###################################################################################################################
###################################################################################################################
#################          Log file and full codes for analyses contained in the paper              ###############
#################                      Oxilia, Menghi Sartorio, Bortolini et. al.                   ###############
#################                      'Exploring Directional and Fluctuating                       ###############
#################                    Asymmetry in the human palate during growth'                   ############### 
#################                                                                                   ###############
#################             submitted to American Journal of Physical Anthropology                ###############
#################                                                                                   ###############
#################                                  March 2021                                       ###############
#################                                                                                   ###############
#################                                   authors:                                        ###############
#################                          Jessica C. Menghi Sartorio,                              ###############
#################                              Eugenio Bortolini,                                   ###############
#################                                Gregorio Oxilia                                    ###############
#################                                                                                   ###############
#################                                    v.1.0                                          ###############
#################                                                                                   ###############
#################                  jessicacristina.menghisartorio@students.uniroma2.eu              ###############
#################                            eugenio.bortolini2@unibo.it                            ###############
#################                             gregorio.oxilia3@unibo.it                             ###############
#################                                                                                   ###############
###################################################################################################################
###################################################################################################################


# using R version 4.0.3


# install missing packages
if (!('geomorph' %in% installed.packages())){
  install.packages('geomorph')}

if (!('Morpho' %in% installed.packages())){
  install.packages('Morpho')}

if (!('shapes' %in% installed.packages())){
  install.packages('shapes')}

if (!('abind' %in% installed.packages())){
  install.packages('abind')}
  
if (!('pegas' %in% installed.packages())){
  install.packages('pegas')}  

if (!('RColorBrewer' %in% installed.packages())){
  install.packages('RColorBrewer')}
  
if (!('plotrix' %in% installed.packages())){
  install.packages('plotrix')}
  
if (!('vegetarian' %in% installed.packages())){
  install.packages('vegetarian')}
  
if (!('vegan' %in% installed.packages())){
  install.packages('vegan')}
  
if (!('FSA' %in% installed.packages())){
  install.packages('FSA')}


# set working directory (replace missing input with chosen path)
setwd("./xxxxxxxxxx/Oxilia_etal_2021_DataAndCodes/Oxilia_etal_2021_dataSource/")
save.image("Oxilia_etal_2021.RData")

# upload required packages into workspace (package version reported below refers to the one used in the paper)
library(geomorph) #3.2.1
library(Morpho)   #2.8
library(shapes)   #1.2.5
library(abind)    #1.4.5
library(pegas)    #0.13
library(RColorBrewer) #1.1.2
library(plotrix)  #3.7.8
library(vegetarian) #1.2
library(vegan)    #2.5.6
library(FSA)      #0.8.32

# upload source code for computing pairwise Procrustes distances
source("pwisedist.R")



########################################################################################################################
####loading data, division by age groups, creation of the dataset, betadisper and PERMANOVA (Bonferroni correction)  ###
####                         to test for differences between Bologna and Florence                                    ###
########################################################################################################################

#############
## GROUP_I ##
#############

coord.classI <- as.matrix(read.table("class_I(5).txt",header=FALSE))
coordata.classI <- array(0, dim= c(41,3,5))
for(i in 0:(5-1)){coordata.classI[,,i+1]<-as.matrix(coord.classI[(41*i+1):(41*i+41),])}
curveslide.classI <- as.matrix(read.table("curveslide.txt",header=T))
ind.classI <- c(1:5)
sample.array.classI <- arrayspecs(coord.classI, 41, 3)
c.classI <- gpagen(sample.array.classI[,,], curves = curveslide.classI, PrinAxes = FALSE, max.iter = 5, ProcD = FALSE, Proj = TRUE)
sample.c.classI <- c.classI$coords
sample.c.Csize.classI <- c.classI$Csize
sample.c.Mean.classI<- c.classI$consensus
sample.c.export.classI <- matrix(0,41*5,3)
for (i in 0:(5-1)) sample.c.export.classI[(41*i+1):(41*i+41),] <- c(sample.c.classI[,,i+1])
sample.c.classI <- arrayspecs(sample.c.export.classI, 41, 3)
sample.c.Mean.classI  <- mshape(sample.c.classI)
sample.c.centered.classI <- array(0,c(41,3,5))
for(i in 1:5) sample.c.centered.classI[,,i] <- sample.c.classI[,,i] - sample.c.Mean.classI

######### betadisper_PERMANOVA #########

class.classI <- as.factor(c(rep("bo",4),rep("fi",1)))
dist.sqr.classI <- sqrt(pwisedist(sample.c.classI))
mod.classI <- betadisper(dist.sqr.classI, class.classI)
anova(mod.classI)
perm.dist.classI <- adonis(dist.sqr.classI~class.classI)
perm.dist.classI


##############
## GROUP_II ##
##############

coord.classII <- as.matrix(read.table("class_II(14).txt",header=FALSE))
coordata.classII <- array(0, dim= c(41,3,14))
for(i in 0:(14-1)){coordata.classII[,,i+1]<-as.matrix(coord.classII[(41*i+1):(41*i+41),])}
curveslide.classII <- as.matrix(read.table("curveslide.txt",header=T))
ind.classII <- c(1:14)
sample.array.classII <- arrayspecs(coord.classII, 41, 3)
c.classII <- gpagen(sample.array.classII[,,], curves = curveslide.classII, PrinAxes = FALSE, max.iter = 5, ProcD = FALSE, Proj = TRUE)
sample.c.classII <- c.classII$coords
sample.c.Csize.classII <- c.classII$Csize
sample.c.Mean.classII<- c.classII$consensus
sample.c.export.classII <- matrix(0,41*14,3)
for (i in 0:(14-1)) sample.c.export.classII[(41*i+1):(41*i+41),] <- c(sample.c.classII[,,i+1])
sample.c.classII <- arrayspecs(sample.c.export.classII, 41, 3)
sample.c.Mean.classII  <- mshape(sample.c.classII)
sample.c.centered.classII <- array(0,c(41,3,14))
for(i in 1:14) sample.c.centered.classII[,,i] <- sample.c.classII[,,i] - sample.c.Mean.classII

######### betadisper_PERMANOVA #########

class.classII <- as.factor(c(rep("bo",11),rep("fi",3)))
dist.sqr.classII <- sqrt(pwisedist(sample.c.classII))
mod.classII <- betadisper(dist.sqr.classII, class.classII)
anova(mod.classII)
perm.dist.classII <- adonis(dist.sqr.classII~class.classII)
perm.dist.classII


###############
## GROUP_III ##
###############

coord.classIII <- as.matrix(read.table("class_III(11).txt",header=FALSE))
coordata.classIII <- array(0, dim= c(41,3,11))
for(i in 0:(11-1)){coordata.classIII[,,i+1]<-as.matrix(coord.classIII[(41*i+1):(41*i+41),])}
curveslide.classIII <- as.matrix(read.table("curveslide.txt",header=T))
ind.classIII <- c(1:11)
sample.array.classIII <- arrayspecs(coord.classIII, 41, 3)
c.classIII <- gpagen(sample.array.classIII[,,], curves = curveslide.classIII, PrinAxes = FALSE, max.iter = 5, ProcD = FALSE, Proj = TRUE)
sample.c.classIII <- c.classIII$coords
sample.c.Csize.classIII <- c.classIII$Csize
sample.c.Mean.classIII <- c.classIII$consensus
sample.c.export.classIII <- matrix(0,41*11,3)
for (i in 0:(11-1)) sample.c.export.classIII[(41*i+1):(41*i+41),] <- c(sample.c.classIII[,,i+1])
sample.c.classIII <- arrayspecs(sample.c.export.classIII, 41, 3)
sample.c.Mean.classIII  <- mshape(sample.c.classIII)
sample.c.centered.classIII <- array(0,c(41,3,11))
for(i in 1:11) sample.c.centered.classIII[,,i] <- sample.c.classIII[,,i] - sample.c.Mean.classIII

######### betadisper_PERMANOVA #########

class.classIII <- as.factor(c(rep("bo",6),rep("fi",5)))
dist.sqr.classIII <- sqrt(pwisedist(sample.c.classIII))
mod.classIII <- betadisper(dist.sqr.classIII, class.classIII)
anova(mod.classIII)
perm.dist.classIII <- adonis(dist.sqr.classIII~class.classIII)
perm.dist.classIII


##############
## GROUP_IV ##
##############

coord.classIV <- as.matrix(read.table("class_IV(26).txt",header=FALSE))
coordata.classIV <- array(0, dim= c(41,3,26))
for(i in 0:(26-1)){coordata.classIV[,,i+1]<-as.matrix(coord.classIV[(41*i+1):(41*i+41),])}
curveslide.classIV <- as.matrix(read.table("curveslide.txt",header=T))
ind.classIV <- c(1:26)
sample.array.classIV <- arrayspecs(coord.classIV, 41, 3)
c.classIV <- gpagen(sample.array.classIV[,,], curves = curveslide.classIV, PrinAxes = FALSE, max.iter = 5, ProcD = FALSE, Proj = TRUE)
sample.c.classIV <- c.classIV$coords
sample.c.Csize.classIV <- c.classIV$Csize
sample.c.Mean.classIV <- c.classIV$consensus
sample.c.export.classIV <- matrix(0,41*26,3)
for (i in 0:(26-1)) sample.c.export.classIV[(41*i+1):(41*i+41),] <- c(sample.c.classIV[,,i+1])
sample.c.classIV <- arrayspecs(sample.c.export.classIV, 41, 3)
sample.c.Mean.classIV  <- mshape(sample.c.classIV)
sample.c.centered.classIV <- array(0,c(41,3,26))
for(i in 1:26) sample.c.centered.classIV[,,i] <- sample.c.classIV[,,i] - sample.c.Mean.classIV

######### betadisper_PERMANOVA #########

class.classIV <- as.factor(c(rep("bo",11),rep("fi",15)))
dist.sqr.classIV <- sqrt(pwisedist(sample.c.classIV))
mod.classIV <- betadisper(dist.sqr.classIV, class.classIV)
anova(mod.classIV)
perm.dist.classIV <- adonis(dist.sqr.classIV~class.classIV)
perm.dist.classIV


#############
## GROUP_V ##
#############

coord.classV <- as.matrix(read.table("class_V(82).txt",header=FALSE))
coordata.classV <- array(0, dim= c(41,3,82))
for(i in 0:(82-1)){coordata.classV[,,i+1]<-as.matrix(coord.classV[(41*i+1):(41*i+41),])}
curveslide.classV <- as.matrix(read.table("curveslide.txt",header=T))
ind.classV <- c(1:82)
sample.array.classV <- arrayspecs(coord.classV, 41, 3)
c.classV <- gpagen(sample.array.classV[,,], curves = curveslide.classV, PrinAxes = FALSE, max.iter = 5, ProcD = FALSE, Proj = TRUE)
sample.c.classV <- c.classV$coords
sample.c.Csize.classV <- c.classV$Csize
sample.c.Mean.classV <- c.classV$consensus
sample.c.export.classV <- matrix(0,41*82,3)
for (i in 0:(82-1)) sample.c.export.classV[(41*i+1):(41*i+41),] <- c(sample.c.classV[,,i+1])
sample.c.classV <- arrayspecs(sample.c.export.classV, 41, 3)
sample.c.Mean.classV  <- mshape(sample.c.classV)
sample.c.centered.classV <- array(0,c(41,3,82))
for(i in 1:82) sample.c.centered.classV[,,i] <- sample.c.classV[,,i] - sample.c.Mean.classV

######### betadisper_PERMANOVA #########

class.classV <- as.factor(c(rep("bo",26),rep("fi",56)))
dist.sqr.classV <- sqrt(pwisedist(sample.c.classV))
mod.classV <- betadisper(dist.sqr.classV, class.classV)
anova(mod.classV)
perm.dist.classV <- adonis(dist.sqr.classV~class.classV)
perm.dist.classV


##############
## GROUP_VI ##
##############

coord.classVI <- as.matrix(read.table("class_VI(45).txt",header=FALSE))
coordata.classVI <- array(0, dim= c(41,3,45))
for(i in 0:(45-1)){coordata.classVI[,,i+1]<-as.matrix(coord.classVI[(41*i+1):(41*i+41),])}
curveslide.classVI <- as.matrix(read.table("curveslide.txt",header=T))
ind.classVI <- c(1:45)
sample.array.classVI <- arrayspecs(coord.classVI, 41, 3)
c.classVI <- gpagen(sample.array.classVI[,,], curves = curveslide.classVI, PrinAxes = FALSE, max.iter = 5, ProcD = FALSE, Proj = TRUE)
sample.c.classVI <- c.classVI$coords
sample.c.Csize.classVI <- c.classVI$Csize
sample.c.Mean.classVI <- c.classVI$consensus
sample.c.export.classVI <- matrix(0,41*45,3)
for (i in 0:(45-1)) sample.c.export.classVI[(41*i+1):(41*i+41),] <- c(sample.c.classVI[,,i+1])
sample.c.classVI <- arrayspecs(sample.c.export.classVI, 41, 3)
sample.c.Mean.classVI  <- mshape(sample.c.classVI)
sample.c.centered.classVI <- array(0,c(41,3,45))
for(i in 1:45) sample.c.centered.classVI[,,i] <- sample.c.classVI[,,i] - sample.c.Mean.classVI

######### betadisper_PERMANOVA #########

class.classVI <- as.factor(c(rep("bo",29),rep("fi",16)))
dist.sqr.classVI <- sqrt(pwisedist(sample.c.classVI))
mod.classVI <- betadisper(dist.sqr.classVI, class.classVI)
anova(mod.classVI)
perm.dist.classVI <- adonis(dist.sqr.classVI~class.classVI)
perm.dist.classVI
#bonferroni_correction
pvals.perm.classes<-c(0.8,0.68,0.39,0.04,0.99,0.90)
which(p.adjust(pvals.perm.classes,"bonferroni")<=0.05)


##############################################################################################################################################
#### Creation of RR copies, Generalised Procrustes Analysis, computation of asymmetries (DA & FA), Procrustes Anova, 3D plot of asymmetry ####
##############################################################################################################################################


###################################################################
## GROUP_I (code structure is repeated for all analysed groups) ###
###################################################################

#Creation of RR copies
landpairs.classI <- as.matrix(read.table("landpairs.txt",header=T));surfslide.classI <- as.matrix(read.table("surfslide.txt",header=T))
dat <- sample.c.classI;dat <- gpagen(dat, print.progress = T, curves= curveslide.classI, surfaces= surfslide.classI);size <- dat$Csize;dat <- dat$coords
ind <- ind.classI;landpairs <- landpairs.classI
n <- dim(dat)[3];k <- dim(dat)[2];p <- dim(dat)[1];nind <- nlevels(ind);spec.names <- dimnames(dat)[[3]]
npairs <- nrow(landpairs)
nl <- p - 2 * npairs
dat2 <- dat;dat2[landpairs[, 1], , ] <- dat[landpairs[, 2], , ];dat2[landpairs[, 2], , ] <- dat[landpairs[, 1], , ];dat2[, 1, ] <- dat2[, 1, ] * (-1)
dat <- array(c(dat, dat2), c(p, k, 2 * n))
ind <- factor(rep(ind, 2));side <- gl(2, n)

#GPA
res <- gpagen(dat, print.progress = T)
dat <- res$coords
Ddat <- two.d.array(dat)
form <- Ddat ~ ind + side;form.cat <- c("ind", "reflection", "indXreflection", "Total")
gdf.dat.classI <- geomorph.data.frame(Ddat = Ddat, ind = ind, side = side)

#Procrustes Anova
proc.classI <- procD.lm(form, data = gdf.dat.classI, RRPP = T,seed = NULL, iter = 499, print.progress = T,effect.type = "F")
stat.classI <- anova(proc.classI, print.progress = FALSE, effect.type = "F")$table;stat.classI$Z[is.nan(stat.classI$Z)] <- NA
MS <- proc.classI$ANOVA$MS
RSS <- proc.classI$ANOVA$RSS
MSE <- RSS/matrix(proc.classI$ANOVA$df[nrow(RSS) + 1], nrow(RSS),ncol(RSS))
randstat.classI <- MS/MSE
rownames(stat.classI) <- form.cat
stat.classI
Dind <- model.matrix(~ind + 0, data = as.data.frame(gdf.dat.classI[-1]))
symm.var.classI <- arrayspecs(coef(lm.fit(Dind, Ddat)), p, k)
spec.names <- substr(dimnames(symm.var.classI)[[3]], start = 4,stop = nchar(dimnames(symm.var.classI)[[3]]));dimnames(symm.var.classI)[[3]] <- spec.names
Dside <- model.matrix(~(side:ind) + 0, data = as.data.frame(gdf.dat.classI[-1]))
mn.symm <- coef(lm.fit(Dside, Ddat))
nlind <- nlevels(ind);nlside <- nlevels(side)
indseq <- seq(nlside, (nlind * nlside), nlside)
asymm.var.classI <- mn.symm[indseq, ] - mn.symm[-indseq,]
mn.dat <- mshape(dat)
asymm.var.classI <- simplify2array(lapply(1:nlind, function(j) {t(matrix(asymm.var.classI[j, ], k, p)) + mn.dat}));dimnames(asymm.var.classI)[[3]] <- spec.names

#computation of asymmetries (DA & FA)
DA <- arrayspecs(coef(.lm.fit(Dside, Ddat)), p, k)
k.classI <- DA
c.classI <- abind(k.classI[,,1],k.classI[,,3],k.classI[,,5],k.classI[,,7],k.classI[,,9],along=3)
d.classI <- abind(k.classI[,,2],k.classI[,,4],k.classI[,,6],k.classI[,,8],k.classI[,,10],along=3)
ms.DA.classI <- mshape(c.classI)- mshape(d.classI)
distanceS<-function(MATRIX1,MATRIX2){sqrt(sum(((MATRIX2 - MATRIX1)^2)))}
DA.classI <- matrix(NA,41,1)
for(i in 1:nrow(mshape(c.classI))){DA.classI[i,]<-distanceS(mshape(c.classI)[i,], mshape(d.classI)[i,])}
DA.classI
FA.classI <- matrix(NA,41,5)
for(i in 1:5){for(j in 1:nrow(ms.DA.classI)){FA.classI[j,i]<-distanceS((c.classI-d.classI)[j,,i], ms.DA.classI[j,])}}
FA.classI

############# 3D plot #############
plotRefToTarget(mshape(dat),mshape(asymm.var.classI),method="points",main="Asymmetry",box=FALSE, axes=FALSE)


##############
## GROUP_II ##
##############

landpairs.classII <- as.matrix(read.table("landpairs.txt",header=T));surfslide.classII <- as.matrix(read.table("surfslide.txt",header=T))
dat <- sample.c.classII;dat <- gpagen(dat, print.progress = T, curves= curveslide.classII, surfaces= surfslide.classII);size <- dat$Csize;dat <- dat$coords
ind <- ind.classII;landpairs <- landpairs.classII
n <- dim(dat)[3];k <- dim(dat)[2];p <- dim(dat)[1];nind <- nlevels(ind);spec.names <- dimnames(dat)[[3]]
npairs <- nrow(landpairs)
nl <- p - 2 * npairs
dat2 <- dat;dat2[landpairs[, 1], , ] <- dat[landpairs[, 2], , ];dat2[landpairs[, 2], , ] <- dat[landpairs[, 1], , ];dat2[, 1, ] <- dat2[, 1, ] * (-1)
dat <- array(c(dat, dat2), c(p, k, 2 * n))
ind <- factor(rep(ind, 2));side <- gl(2, n)
res <- gpagen(dat, print.progress = T)
dat <- res$coords
Ddat <- two.d.array(dat)
form <- Ddat ~ ind + side;form.cat <- c("ind", "reflection", "indXreflection", "Total")
gdf.dat.classII <- geomorph.data.frame(Ddat = Ddat, ind = ind, side = side)
proc.classII <- procD.lm(form, data = gdf.dat.classII, RRPP = T,seed = NULL, iter = 499, print.progress = T,effect.type = "F")
stat.classII <- anova(proc.classII, print.progress = FALSE, effect.type = "F")$table;stat.classII$Z[is.nan(stat.classII$Z)] <- NA
MS <- proc.classII$ANOVA$MS
RSS <- proc.classII$ANOVA$RSS
MSE <- RSS/matrix(proc.classII$ANOVA$df[nrow(RSS) + 1], nrow(RSS),ncol(RSS))
randstat.classII <- MS/MSE
rownames(stat.classII) <- form.cat
stat.classII
Dind <- model.matrix(~ind + 0, data = as.data.frame(gdf.dat.classII[-1]))
symm.var.classII <- arrayspecs(coef(lm.fit(Dind, Ddat)), p, k)
spec.names <- substr(dimnames(symm.var.classII)[[3]], start = 4,stop = nchar(dimnames(symm.var.classII)[[3]]));dimnames(symm.var.classII)[[3]] <- spec.names
Dside <- model.matrix(~(side:ind) + 0, data = as.data.frame(gdf.dat.classII[-1]))
mn.symm <- coef(lm.fit(Dside, Ddat))
nlind <- nlevels(ind);nlside <- nlevels(side)
indseq <- seq(nlside, (nlind * nlside), nlside)
asymm.var.classII <- mn.symm[indseq, ] - mn.symm[-indseq,]
mn.dat <- mshape(dat)
asymm.var.classII <- simplify2array(lapply(1:nlind, function(j) {t(matrix(asymm.var.classII[j, ], k, p)) + mn.dat}));dimnames(asymm.var.classII)[[3]] <- spec.names
DA <- arrayspecs(coef(.lm.fit(Dside, Ddat)), p, k)
k.classII <- DA
c.classII <- abind(k.classII[,,1],k.classII[,,3],k.classII[,,5],k.classII[,,7],k.classII[,,9],k.classII[,,11],k.classII[,,13],k.classII[,,15],k.classII[,,17],k.classII[,,19],k.classII[,,21],k.classII[,,23],k.classII[,,25],k.classII[,,27],along=3)
d.classII <- abind(k.classII[,,2],k.classII[,,4],k.classII[,,6],k.classII[,,8],k.classII[,,10],k.classII[,,12],k.classII[,,14],k.classII[,,16],k.classII[,,18],k.classII[,,20],k.classII[,,22],k.classII[,,24],k.classII[,,26],k.classII[,,28],along=3)
ms.DA.classII <- mshape(c.classII)- mshape(d.classII)
DA.classII <- matrix(NA,41,1)
for(i in 1:nrow(mshape(c.classII))){DA.classII[i,]<-distanceS(mshape(c.classII)[i,], mshape(d.classII)[i,])}
DA.classII
FA.classII <- matrix(NA,41,14)
for(i in 1:14){for(j in 1:nrow(ms.DA.classII)){FA.classII[j,i]<-distanceS((c.classII-d.classII)[j,,i], ms.DA.classII[j,])}}
FA.classII

############# plot #############
plotRefToTarget(mshape(dat),mshape(asymm.var.classII),method="points",main="Asymmetry",box=FALSE, axes=FALSE)


###############
## GROUP_III ##
###############

landpairs.classIII <- as.matrix(read.table("landpairs.txt",header=T));surfslide.classIII <- as.matrix(read.table("surfslide.txt",header=T))
dat <- sample.c.classIII;dat <- gpagen(dat, print.progress = T, curves= curveslide.classIII, surfaces= surfslide.classIII);size <- dat$Csize;dat <- dat$coords
ind <- ind.classIII;landpairs <- landpairs.classIII
n <- dim(dat)[3];k <- dim(dat)[2];p <- dim(dat)[1];nind <- nlevels(ind);spec.names <- dimnames(dat)[[3]]
npairs <- nrow(landpairs)
nl <- p - 2 * npairs
dat2 <- dat;dat2[landpairs[, 1], , ] <- dat[landpairs[, 2], , ];dat2[landpairs[, 2], , ] <- dat[landpairs[, 1], , ];dat2[, 1, ] <- dat2[, 1, ] * (-1)
dat <- array(c(dat, dat2), c(p, k, 2 * n))
ind <- factor(rep(ind, 2));side <- gl(2, n)
res <- gpagen(dat, print.progress = T)
dat <- res$coords
Ddat <- two.d.array(dat)
form <- Ddat ~ ind + side;form.cat <- c("ind", "reflection", "indXreflection", "Total")
gdf.dat.classIII <- geomorph.data.frame(Ddat = Ddat, ind = ind, side = side)
proc.classIII <- procD.lm(form, data = gdf.dat.classIII, RRPP = T,seed = NULL, iter = 499, print.progress = T,effect.type = "F")
stat.classIII <- anova(proc.classIII, print.progress = FALSE, effect.type = "F")$table;stat.classIII$Z[is.nan(stat.classIII$Z)] <- NA
MS <- proc.classIII$ANOVA$MS
RSS <- proc.classIII$ANOVA$RSS
MSE <- RSS/matrix(proc.classIII$ANOVA$df[nrow(RSS) + 1], nrow(RSS),ncol(RSS))
randstat.classIII <- MS/MSE
rownames(stat.classIII) <- form.cat
stat.classIII
Dind <- model.matrix(~ind + 0, data = as.data.frame(gdf.dat.classIII[-1]))
symm.var.classIII <- arrayspecs(coef(lm.fit(Dind, Ddat)), p, k)
spec.names <- substr(dimnames(symm.var.classIII)[[3]], start = 4,stop = nchar(dimnames(symm.var.classIII)[[3]]));dimnames(symm.var.classIII)[[3]] <- spec.names
Dside <- model.matrix(~(side:ind) + 0, data = as.data.frame(gdf.dat.classIII[-1]))
mn.symm <- coef(lm.fit(Dside, Ddat))
nlind <- nlevels(ind);nlside <- nlevels(side)
indseq <- seq(nlside, (nlind * nlside), nlside)
asymm.var.classIII <- mn.symm[indseq, ] - mn.symm[-indseq,]
mn.dat <- mshape(dat)
asymm.var.classIII <- simplify2array(lapply(1:nlind, function(j) {t(matrix(asymm.var.classIII[j, ], k, p)) + mn.dat}));dimnames(asymm.var.classIII)[[3]] <- spec.names
DA <- arrayspecs(coef(.lm.fit(Dside, Ddat)), p, k)
k.classIII <- DA
c.classIII <- abind(k.classIII[,,1],k.classIII[,,3],k.classIII[,,5],k.classIII[,,7],k.classIII[,,9],k.classIII[,,11],k.classIII[,,13],k.classIII[,,15],k.classIII[,,17],k.classIII[,,19],k.classIII[,,21],along=3)
d.classIII <- abind(k.classIII[,,2],k.classIII[,,4],k.classIII[,,6],k.classIII[,,8],k.classIII[,,10],k.classIII[,,12],k.classIII[,,14],k.classIII[,,16],k.classIII[,,18],k.classIII[,,20],k.classIII[,,22],along=3)
ms.DA.classIII <- mshape(c.classIII)- mshape(d.classIII)
DA.classIII <- matrix(NA,41,1)
for(i in 1:nrow(mshape(c.classIII))){DA.classIII[i,]<-distanceS(mshape(c.classIII)[i,], mshape(d.classIII)[i,])}
DA.classIII
FA.classIII <- matrix(NA,41,11)
for(i in 1:11){for(j in 1:nrow(ms.DA.classIII)){FA.classIII[j,i]<-distanceS((c.classIII-d.classIII)[j,,i], ms.DA.classIII[j,])}}
FA.classIII

############# plot #############
plotRefToTarget(mshape(dat),mshape(asymm.var.classIII),method="points",main="Asymmetry",box=FALSE, axes=FALSE)


##############
## GROUP_IV ##
##############

landpairs.classIV <- as.matrix(read.table("landpairs.txt",header=T));surfslide.classIV <- as.matrix(read.table("surfslide.txt",header=T))
dat <- sample.c.classIV;dat <- gpagen(dat, print.progress = T, curves= curveslide.classIV, surfaces= surfslide.classIV);size <- dat$Csize;dat <- dat$coords
ind <- ind.classIV;landpairs <- landpairs.classIV
n <- dim(dat)[3];k <- dim(dat)[2];p <- dim(dat)[1];nind <- nlevels(ind);spec.names <- dimnames(dat)[[3]]
npairs <- nrow(landpairs)
nl <- p - 2 * npairs
dat2 <- dat;dat2[landpairs[, 1], , ] <- dat[landpairs[, 2], , ];dat2[landpairs[, 2], , ] <- dat[landpairs[, 1], , ];dat2[, 1, ] <- dat2[, 1, ] * (-1)
dat <- array(c(dat, dat2), c(p, k, 2 * n))
ind <- factor(rep(ind, 2));side <- gl(2, n)
res <- gpagen(dat, print.progress = T)
dat <- res$coords
Ddat <- two.d.array(dat)
form <- Ddat ~ ind + side;form.cat <- c("ind", "reflection", "indXreflection", "Total")
gdf.dat.classIV <- geomorph.data.frame(Ddat = Ddat, ind = ind, side = side)
proc.classIV <- procD.lm(form, data = gdf.dat.classIV, RRPP = T,seed = NULL, iter = 499, print.progress = T,effect.type = "F")
stat.classIV <- anova(proc.classIV, print.progress = FALSE, effect.type = "F")$table;stat.classIV$Z[is.nan(stat.classIV$Z)] <- NA
MS <- proc.classIV$ANOVA$MS
RSS <- proc.classIV$ANOVA$RSS
MSE <- RSS/matrix(proc.classIV$ANOVA$df[nrow(RSS) + 1], nrow(RSS),ncol(RSS))
randstat.classIV <- MS/MSE
rownames(stat.classIV) <- form.cat
stat.classIV
Dind <- model.matrix(~ind + 0, data = as.data.frame(gdf.dat.classIV[-1]))
symm.var.classIV <- arrayspecs(coef(lm.fit(Dind, Ddat)), p, k)
spec.names <- substr(dimnames(symm.var.classIV)[[3]], start = 4,stop = nchar(dimnames(symm.var.classIV)[[3]]));dimnames(symm.var.classIV)[[3]] <- spec.names
Dside <- model.matrix(~(side:ind) + 0, data = as.data.frame(gdf.dat.classIV[-1]))
mn.symm <- coef(lm.fit(Dside, Ddat))
nlind <- nlevels(ind);nlside <- nlevels(side)
indseq <- seq(nlside, (nlind * nlside), nlside)
asymm.var.classIV <- mn.symm[indseq, ] - mn.symm[-indseq,]
mn.dat <- mshape(dat)
asymm.var.classIV <- simplify2array(lapply(1:nlind, function(j) {t(matrix(asymm.var.classIV[j, ], k, p)) + mn.dat}));dimnames(asymm.var.classIV)[[3]] <- spec.names
DA <- arrayspecs(coef(.lm.fit(Dside, Ddat)), p, k)
k.classIV <- DA
c.classIV <- abind(k.classIV[,,1],k.classIV[,,3],k.classIV[,,5],k.classIV[,,7],k.classIV[,,9],k.classIV[,,11],k.classIV[,,13],k.classIV[,,15],k.classIV[,,17],k.classIV[,,19],k.classIV[,,21],k.classIV[,,23],k.classIV[,,25],k.classIV[,,27],k.classIV[,,29],k.classIV[,,31],k.classIV[,,33],k.classIV[,,35],k.classIV[,,37],k.classIV[,,39],k.classIV[,,41],k.classIV[,,43],k.classIV[,,45],k.classIV[,,47],k.classIV[,,49],k.classIV[,,51],along=3)
d.classIV <- abind(k.classIV[,,2],k.classIV[,,4],k.classIV[,,6],k.classIV[,,8],k.classIV[,,10],k.classIV[,,12],k.classIV[,,14],k.classIV[,,16],k.classIV[,,18],k.classIV[,,20],k.classIV[,,22],k.classIV[,,24],k.classIV[,,26],k.classIV[,,28],k.classIV[,,30],k.classIV[,,32],k.classIV[,,34],k.classIV[,,36],k.classIV[,,38],k.classIV[,,40],k.classIV[,,42],k.classIV[,,44],k.classIV[,,46],k.classIV[,,48],k.classIV[,,50],k.classIV[,,52],along=3)
ms.DA.classIV <- mshape(c.classIV)- mshape(d.classIV)
DA.classIV <- matrix(NA,41,1)
for(i in 1:nrow(mshape(c.classIV))){DA.classIV[i,]<-distanceS(mshape(c.classIV)[i,], mshape(d.classIV)[i,])}
DA.classIV
FA.classIV <- matrix(NA,41,26)
for(i in 1:26){for(j in 1:nrow(ms.DA.classIV)){FA.classIV[j,i]<-distanceS((c.classIV-d.classIV)[j,,i], ms.DA.classIV[j,])}}
FA.classIV

############# plot #############
plotRefToTarget(mshape(dat),mshape(asymm.var.classIV),method="points",main="Asymmetry",box=FALSE, axes=FALSE)


#############
## GROUP_V ##
#############

landpairs.classV <- as.matrix(read.table("landpairs.txt",header=T));surfslide.classV <- as.matrix(read.table("surfslide.txt",header=T))
dat <- sample.c.classV;dat <- gpagen(dat, print.progress = T, curves= curveslide.classV, surfaces= surfslide.classV);size <- dat$Csize;dat <- dat$coords
ind <- ind.classV;landpairs <- landpairs.classV
n <- dim(dat)[3];k <- dim(dat)[2];p <- dim(dat)[1];nind <- nlevels(ind);spec.names <- dimnames(dat)[[3]]
npairs <- nrow(landpairs)
nl <- p - 2 * npairs
dat2 <- dat;dat2[landpairs[, 1], , ] <- dat[landpairs[, 2], , ];dat2[landpairs[, 2], , ] <- dat[landpairs[, 1], , ];dat2[, 1, ] <- dat2[, 1, ] * (-1)
dat <- array(c(dat, dat2), c(p, k, 2 * n))
ind <- factor(rep(ind, 2));side <- gl(2, n)
res <- gpagen(dat, print.progress = T)
dat <- res$coords
Ddat <- two.d.array(dat)
form <- Ddat ~ ind + side;form.cat <- c("ind", "reflection", "indXreflection", "Total")
gdf.dat.classV <- geomorph.data.frame(Ddat = Ddat, ind = ind, side = side)
proc.classV <- procD.lm(form, data = gdf.dat.classV, RRPP = T,seed = NULL, iter = 499, print.progress = T,effect.type = "F")
stat.classV <- anova(proc.classV, print.progress = FALSE, effect.type = "F")$table;stat.classV$Z[is.nan(stat.classV$Z)] <- NA
MS <- proc.classV$ANOVA$MS
RSS <- proc.classV$ANOVA$RSS
MSE <- RSS/matrix(proc.classV$ANOVA$df[nrow(RSS) + 1], nrow(RSS),ncol(RSS))
randstat.classV <- MS/MSE
rownames(stat.classV) <- form.cat
stat.classV
Dind <- model.matrix(~ind + 0, data = as.data.frame(gdf.dat.classV[-1]))
symm.var.classV <- arrayspecs(coef(lm.fit(Dind, Ddat)), p, k)
spec.names <- substr(dimnames(symm.var.classV)[[3]], start = 4,stop = nchar(dimnames(symm.var.classV)[[3]]));dimnames(symm.var.classV)[[3]] <- spec.names
Dside <- model.matrix(~(side:ind) + 0, data = as.data.frame(gdf.dat.classV[-1]))
mn.symm <- coef(lm.fit(Dside, Ddat))
nlind <- nlevels(ind);nlside <- nlevels(side)
indseq <- seq(nlside, (nlind * nlside), nlside)
asymm.var.classV <- mn.symm[indseq, ] - mn.symm[-indseq,]
mn.dat <- mshape(dat)
asymm.var.classV <- simplify2array(lapply(1:nlind, function(j) {t(matrix(asymm.var.classV[j, ], k, p)) + mn.dat}));dimnames(asymm.var.classV)[[3]] <- spec.names
DA <- arrayspecs(coef(.lm.fit(Dside, Ddat)), p, k)
k.classV <- DA
c.classV <- abind(k.classV[,,1],k.classV[,,3],k.classV[,,5],k.classV[,,7],k.classV[,,9],k.classV[,,11],k.classV[,,13],k.classV[,,15],k.classV[,,17],k.classV[,,19],k.classV[,,21],k.classV[,,23],k.classV[,,25],k.classV[,,27],k.classV[,,29],k.classV[,,31],k.classV[,,33],k.classV[,,35],k.classV[,,37],k.classV[,,39],k.classV[,,41],k.classV[,,43],k.classV[,,45],k.classV[,,47],k.classV[,,49],k.classV[,,51],k.classV[,,53],k.classV[,,55],k.classV[,,57],k.classV[,,59],k.classV[,,61],k.classV[,,63],k.classV[,,65],k.classV[,,67],k.classV[,,69],k.classV[,,71],k.classV[,,73],k.classV[,,75],k.classV[,,77],k.classV[,,79],k.classV[,,81],k.classV[,,83],k.classV[,,85],k.classV[,,87],k.classV[,,89],k.classV[,,91],k.classV[,,93],k.classV[,,95],k.classV[,,97],k.classV[,,99],k.classV[,,101],k.classV[,,103],k.classV[,,105],k.classV[,,107],k.classV[,,109],k.classV[,,111],k.classV[,,113],k.classV[,,115],k.classV[,,117],k.classV[,,119],k.classV[,,121],k.classV[,,123],k.classV[,,125],k.classV[,,127],k.classV[,,129],k.classV[,,131],k.classV[,,133],k.classV[,,135],k.classV[,,137],k.classV[,,139],k.classV[,,141],k.classV[,,143],k.classV[,,145],k.classV[,,147],k.classV[,,149],k.classV[,,151],k.classV[,,153],k.classV[,,155],k.classV[,,157],k.classV[,,159],k.classV[,,161],k.classV[,,163],along=3)
d.classV <- abind(k.classV[,,2],k.classV[,,4],k.classV[,,6],k.classV[,,8],k.classV[,,10],k.classV[,,12],k.classV[,,14],k.classV[,,16],k.classV[,,18],k.classV[,,20],k.classV[,,22],k.classV[,,24],k.classV[,,26],k.classV[,,28],k.classV[,,30],k.classV[,,32],k.classV[,,34],k.classV[,,36],k.classV[,,38],k.classV[,,40],k.classV[,,42],k.classV[,,44],k.classV[,,46],k.classV[,,48],k.classV[,,50],k.classV[,,52],k.classV[,,54],k.classV[,,56],k.classV[,,58],k.classV[,,60],k.classV[,,62],k.classV[,,64],k.classV[,,66],k.classV[,,68],k.classV[,,70],k.classV[,,72],k.classV[,,74],k.classV[,,76],k.classV[,,78],k.classV[,,80],k.classV[,,82],k.classV[,,84],k.classV[,,86],k.classV[,,88],k.classV[,,90],k.classV[,,92],k.classV[,,94],k.classV[,,96],k.classV[,,98],k.classV[,,100],k.classV[,,102],k.classV[,,104],k.classV[,,106],k.classV[,,108],k.classV[,,110],k.classV[,,112],k.classV[,,114],k.classV[,,116],k.classV[,,118],k.classV[,,120],k.classV[,,122],k.classV[,,124],k.classV[,,126],k.classV[,,128],k.classV[,,130],k.classV[,,132],k.classV[,,134],k.classV[,,136],k.classV[,,138],k.classV[,,140],k.classV[,,142],k.classV[,,144],k.classV[,,146],k.classV[,,148],k.classV[,,150],k.classV[,,152],k.classV[,,154],k.classV[,,156],k.classV[,,158],k.classV[,,160],k.classV[,,162],k.classV[,,164],along=3)
ms.DA.classV <- mshape(c.classV)- mshape(d.classV)
DA.classV <- matrix(NA,41,1)
for(i in 1:nrow(mshape(c.classV))){DA.classV[i,]<-distanceS(mshape(c.classV)[i,], mshape(d.classV)[i,])}
DA.classV
FA.classV <- matrix(NA,41,82)
for(i in 1:82){for(j in 1:nrow(ms.DA.classV)){FA.classV[j,i]<-distanceS((c.classV-d.classV)[j,,i], ms.DA.classV[j,])}}
FA.classV

############# plot #############
plotRefToTarget(mshape(dat),mshape(asymm.var.classV),method="points",main="Asymmetry",box=FALSE, axes=FALSE)


##############
## GROUP_VI ##
##############

landpairs.classVI <- as.matrix(read.table("landpairs.txt",header=T));surfslide.classVI <- as.matrix(read.table("surfslide.txt",header=T))
dat <- sample.c.classVI;dat <- gpagen(dat, print.progress = T, curves= curveslide.classVI, surfaces= surfslide.classVI);size <- dat$Csize;dat <- dat$coords
ind <- ind.classVI;landpairs <- landpairs.classVI
n <- dim(dat)[3];k <- dim(dat)[2];p <- dim(dat)[1];nind <- nlevels(ind);spec.names <- dimnames(dat)[[3]]
npairs <- nrow(landpairs)
nl <- p - 2 * npairs
dat2 <- dat;dat2[landpairs[, 1], , ] <- dat[landpairs[, 2], , ];dat2[landpairs[, 2], , ] <- dat[landpairs[, 1], , ];dat2[, 1, ] <- dat2[, 1, ] * (-1)
dat <- array(c(dat, dat2), c(p, k, 2 * n))
ind <- factor(rep(ind, 2));side <- gl(2, n)
res <- gpagen(dat, print.progress = T)
dat <- res$coords
Ddat <- two.d.array(dat)
form <- Ddat ~ ind + side;form.cat <- c("ind", "reflection", "indXreflection", "Total")
gdf.dat.classVI <- geomorph.data.frame(Ddat = Ddat, ind = ind, side = side)
proc.classVI <- procD.lm(form, data = gdf.dat.classVI, RRPP = T,seed = NULL, iter = 499, print.progress = T,effect.type = "F")
stat.classVI <- anova(proc.classVI, print.progress = FALSE, effect.type = "F")$table;stat.classVI$Z[is.nan(stat.classVI$Z)] <- NA
MS <- proc.classVI$ANOVA$MS
RSS <- proc.classVI$ANOVA$RSS
MSE <- RSS/matrix(proc.classVI$ANOVA$df[nrow(RSS) + 1], nrow(RSS),ncol(RSS))
randstat.classVI <- MS/MSE
rownames(stat.classVI) <- form.cat
stat.classVI
Dind <- model.matrix(~ind + 0, data = as.data.frame(gdf.dat.classVI[-1]))
symm.var.classVI <- arrayspecs(coef(lm.fit(Dind, Ddat)), p, k)
spec.names <- substr(dimnames(symm.var.classVI)[[3]], start = 4,stop = nchar(dimnames(symm.var.classVI)[[3]]));dimnames(symm.var.classVI)[[3]] <- spec.names
Dside <- model.matrix(~(side:ind) + 0, data = as.data.frame(gdf.dat.classVI[-1]))
mn.symm <- coef(lm.fit(Dside, Ddat))
nlind <- nlevels(ind);nlside <- nlevels(side)
indseq <- seq(nlside, (nlind * nlside), nlside)
asymm.var.classVI <- mn.symm[indseq, ] - mn.symm[-indseq,]
mn.dat <- mshape(dat)
asymm.var.classVI <- simplify2array(lapply(1:nlind, function(j) {t(matrix(asymm.var.classVI[j, ], k, p)) + mn.dat}));dimnames(asymm.var.classVI)[[3]] <- spec.names
DA <- arrayspecs(coef(.lm.fit(Dside, Ddat)), p, k)
k.classVI <- DA
c.classVI <- abind(k.classVI[,,1],k.classVI[,,3],k.classVI[,,5],k.classVI[,,7],k.classVI[,,9],k.classVI[,,11],k.classVI[,,13],k.classVI[,,15],k.classVI[,,17],k.classVI[,,19],k.classVI[,,21],k.classVI[,,23],k.classVI[,,25],k.classVI[,,27],k.classVI[,,29],k.classVI[,,31],k.classVI[,,33],k.classVI[,,35],k.classVI[,,37],k.classVI[,,39],k.classVI[,,41],k.classVI[,,43],k.classVI[,,45],k.classVI[,,47],k.classVI[,,49],k.classVI[,,51],k.classVI[,,53],k.classVI[,,55],k.classVI[,,57],k.classVI[,,59],k.classVI[,,61],k.classVI[,,63],k.classVI[,,65],k.classVI[,,67],k.classVI[,,69],k.classVI[,,71],k.classVI[,,73],k.classVI[,,75],k.classVI[,,77],k.classVI[,,79],k.classVI[,,81],k.classVI[,,83],k.classVI[,,85],k.classVI[,,87],k.classVI[,,89],along=3)
d.classVI <- abind(k.classVI[,,2],k.classVI[,,4],k.classVI[,,6],k.classVI[,,8],k.classVI[,,10],k.classVI[,,12],k.classVI[,,14],k.classVI[,,16],k.classVI[,,18],k.classVI[,,20],k.classVI[,,22],k.classVI[,,24],k.classVI[,,26],k.classVI[,,28],k.classVI[,,30],k.classVI[,,32],k.classVI[,,34],k.classVI[,,36],k.classVI[,,38],k.classVI[,,40],k.classVI[,,42],k.classVI[,,44],k.classVI[,,46],k.classVI[,,48],k.classVI[,,50],k.classVI[,,52],k.classVI[,,54],k.classVI[,,56],k.classVI[,,58],k.classVI[,,60],k.classVI[,,62],k.classVI[,,64],k.classVI[,,66],k.classVI[,,68],k.classVI[,,70],k.classVI[,,72],k.classVI[,,74],k.classVI[,,76],k.classVI[,,78],k.classVI[,,80],k.classVI[,,82],k.classVI[,,84],k.classVI[,,86],k.classVI[,,88],k.classVI[,,90],along=3)
ms.DA.classVI <- mshape(c.classVI)- mshape(d.classVI)
DA.classVI <- matrix(NA,41,1)
for(i in 1:nrow(mshape(c.classVI))){DA.classVI[i,]<-distanceS(mshape(c.classVI)[i,], mshape(d.classVI)[i,])}
DA.classVI
FA.classVI <- matrix(NA,41,45)
for(i in 1:45){for(j in 1:nrow(ms.DA.classVI)){FA.classVI[j,i]<-distanceS((c.classVI-d.classVI)[j,,i], ms.DA.classVI[j,])}}
FA.classVI

############# plot #############
plotRefToTarget(mshape(dat),mshape(asymm.var.classVI),method="points",main="Asymmetry",box=FALSE, axes=FALSE)


####################################################################
#### Computation of asymmetries (DA & FA) for M/F group IV-V-VI ####
####################################################################

##############
## GROUP_IV ##
##############

ind.classIV_M <- c(1:11)
ind.classIV_F <- c(1:14)
sample.c.classIV <-sample.c.classIV[,,-20]
sample.c.classIV_M <- sample.c.classIV[,,-c(4,6:10,12:13,15,18,20,22,24:25)]
sample.c.classIV_F <- sample.c.classIV[,,c(4,6:10,12:13,15,18,20,22,24:25)]
landpairs.classIV_M <- as.matrix(read.table("landpairs.txt",header=T));surfslide.classIV_M <- as.matrix(read.table("surfslide.txt",header=T))
dat <- sample.c.classIV_M;dat <- gpagen(dat, print.progress = T, curves= curveslide.classIV, surfaces= surfslide.classIV_M);size <- dat$Csize;dat <- dat$coords
ind <- ind.classIV_M;landpairs <- landpairs.classIV_M
n <- dim(dat)[3];k <- dim(dat)[2];p <- dim(dat)[1];nind <- nlevels(ind);spec.names <- dimnames(dat)[[3]]
npairs <- nrow(landpairs)
nl <- p - 2 * npairs
dat2 <- dat;dat2[landpairs[, 1], , ] <- dat[landpairs[, 2], , ];dat2[landpairs[, 2], , ] <- dat[landpairs[, 1], , ];dat2[, 1, ] <- dat2[, 1, ] * (-1)
dat <- array(c(dat, dat2), c(p, k, 2 * n))
ind <- factor(rep(ind, 2));side <- gl(2, n)
res <- gpagen(dat, print.progress = T)
dat <- res$coords
Ddat <- two.d.array(dat)
form <- Ddat ~ ind + side;form.cat <- c("ind", "reflection", "indXreflection", "Total")
gdf.dat.classIV_M <- geomorph.data.frame(Ddat = Ddat, ind = ind, side = side)
proc.classIV_M <- procD.lm(form, data = gdf.dat.classIV_M, RRPP = T,seed = NULL, iter = 499, print.progress = T,effect.type = "F")
stat.classIV_M <- anova(proc.classIV_M, print.progress = FALSE, effect.type = "F")$table;stat.classIV_M$Z[is.nan(stat.classIV_M$Z)] <- NA
MS <- proc.classIV_M$ANOVA$MS
RSS <- proc.classIV_M$ANOVA$RSS
MSE <- RSS/matrix(proc.classIV_M$ANOVA$df[nrow(RSS) + 1], nrow(RSS),ncol(RSS))
randstat.classIV_M <- MS/MSE
rownames(stat.classIV_M) <- form.cat
Dind <- model.matrix(~ind + 0, data = as.data.frame(gdf.dat.classIV_M[-1]))
symm.var.classIV_M <- arrayspecs(coef(lm.fit(Dind, Ddat)), p, k)
spec.names <- substr(dimnames(symm.var.classIV_M)[[3]], start = 4,stop = nchar(dimnames(symm.var.classIV_M)[[3]]));dimnames(symm.var.classIV_M)[[3]] <- spec.names
Dside <- model.matrix(~(side:ind) + 0, data = as.data.frame(gdf.dat.classIV_M[-1]))
mn.symm <- coef(lm.fit(Dside, Ddat))
nlind <- nlevels(ind);nlside <- nlevels(side)
indseq <- seq(nlside, (nlind * nlside), nlside)
asymm.var.classIV_M <- mn.symm[indseq, ] - mn.symm[-indseq,]
mn.dat <- mshape(dat)
asymm.var.classIV_M <- simplify2array(lapply(1:nlind, function(j) {t(matrix(asymm.var.classIV_M[j, ], k, p)) + mn.dat}));dimnames(asymm.var.classIV_M)[[3]] <- spec.names
DA <- arrayspecs(coef(.lm.fit(Dside, Ddat)), p, k)
k.classIV_M <- DA
c.classIV_M <- abind(k.classIV_M[,,1],k.classIV_M[,,3],k.classIV_M[,,5],k.classIV_M[,,7],k.classIV_M[,,9],k.classIV_M[,,11],k.classIV_M[,,13],k.classIV_M[,,15],k.classIV_M[,,17],k.classIV_M[,,19],k.classIV_M[,,21],along=3)
d.classIV_M <- abind(k.classIV_M[,,2],k.classIV_M[,,4],k.classIV_M[,,6],k.classIV_M[,,8],k.classIV_M[,,10],k.classIV_M[,,12],k.classIV_M[,,14],k.classIV_M[,,16],k.classIV_M[,,18],k.classIV_M[,,20],k.classIV_M[,,22],along=3)
ms.DA.classIV_M <- mshape(c.classIV_M)- mshape(d.classIV_M)
DA.classIV_M <- matrix(NA,41,1)
for(i in 1:nrow(mshape(c.classIV_M))){DA.classIV_M[i,]<-distanceS(mshape(c.classIV_M)[i,], mshape(d.classIV_M)[i,])}
DA.classIV_M
FA.classIV_M <- matrix(NA,41,11)
for(i in 1:11){for(j in 1:nrow(ms.DA.classIV_M)){FA.classIV_M[j,i]<-distanceS((c.classIV_M-d.classIV_M)[j,,i], ms.DA.classIV_M[j,])}}
FA.classIV_M

landpairs.classIV_F <- as.matrix(read.table("landpairs.txt",header=T));surfslide.classIV_F <- as.matrix(read.table("surfslide.txt",header=T))
dat <- sample.c.classIV_F;dat <- gpagen(dat, print.progress = T, curves= curveslide.classIV, surfaces= surfslide.classIV_F);size <- dat$Csize;dat <- dat$coords
ind <- ind.classIV_F;landpairs <- landpairs.classIV_F
n <- dim(dat)[3];k <- dim(dat)[2];p <- dim(dat)[1];nind <- nlevels(ind);spec.names <- dimnames(dat)[[3]]
npairs <- nrow(landpairs)
nl <- p - 2 * npairs
dat2 <- dat;dat2[landpairs[, 1], , ] <- dat[landpairs[, 2], , ];dat2[landpairs[, 2], , ] <- dat[landpairs[, 1], , ];dat2[, 1, ] <- dat2[, 1, ] * (-1)
dat <- array(c(dat, dat2), c(p, k, 2 * n))
ind <- factor(rep(ind, 2));side <- gl(2, n)
res <- gpagen(dat, print.progress = T)
dat <- res$coords
Ddat <- two.d.array(dat)
form <- Ddat ~ ind + side;form.cat <- c("ind", "reflection", "indXreflection", "Total")
gdf.dat.classIV_F <- geomorph.data.frame(Ddat = Ddat, ind = ind, side = side)
proc.classIV_F <- procD.lm(form, data = gdf.dat.classIV_F, RRPP = T,seed = NULL, iter = 499, print.progress = T,effect.type = "F")
stat.classIV_F <- anova(proc.classIV_F, print.progress = FALSE, effect.type = "F")$table;stat.classIV_F$Z[is.nan(stat.classIV_F$Z)] <- NA
MS <- proc.classIV_F$ANOVA$MS
RSS <- proc.classIV_F$ANOVA$RSS
MSE <- RSS/matrix(proc.classIV_F$ANOVA$df[nrow(RSS) + 1], nrow(RSS),ncol(RSS))
randstat.classIV_F <- MS/MSE
rownames(stat.classIV_F) <- form.cat
Dind <- model.matrix(~ind + 0, data = as.data.frame(gdf.dat.classIV_F[-1]))
symm.var.classIV_F <- arrayspecs(coef(lm.fit(Dind, Ddat)), p, k)
spec.names <- substr(dimnames(symm.var.classIV_F)[[3]], start = 4,stop = nchar(dimnames(symm.var.classIV_F)[[3]]));dimnames(symm.var.classIV_F)[[3]] <- spec.names
Dside <- model.matrix(~(side:ind) + 0, data = as.data.frame(gdf.dat.classIV_F[-1]))
mn.symm <- coef(lm.fit(Dside, Ddat))
nlind <- nlevels(ind);nlside <- nlevels(side)
indseq <- seq(nlside, (nlind * nlside), nlside)
asymm.var.classIV_F <- mn.symm[indseq, ] - mn.symm[-indseq,]
mn.dat <- mshape(dat)
asymm.var.classIV_F <- simplify2array(lapply(1:nlind, function(j) {t(matrix(asymm.var.classIV_F[j, ], k, p)) + mn.dat}));dimnames(asymm.var.classIV_F)[[3]] <- spec.names
DA <- arrayspecs(coef(.lm.fit(Dside, Ddat)), p, k)
k.classIV_F <- DA
c.classIV_F <- abind(k.classIV_F[,,1],k.classIV_F[,,3],k.classIV_F[,,5],k.classIV_F[,,7],k.classIV_F[,,9],k.classIV_F[,,11],k.classIV_F[,,13],k.classIV_F[,,15],k.classIV_F[,,17],k.classIV_F[,,19],k.classIV_F[,,21],k.classIV_F[,,23],k.classIV_F[,,25],k.classIV_F[,,27],along=3)
d.classIV_F <- abind(k.classIV_F[,,2],k.classIV_F[,,4],k.classIV_F[,,6],k.classIV_F[,,8],k.classIV_F[,,10],k.classIV_F[,,12],k.classIV_F[,,14],k.classIV_F[,,16],k.classIV_F[,,18],k.classIV_F[,,20],k.classIV_F[,,22],k.classIV_F[,,24],k.classIV_F[,,26],k.classIV_F[,,28],along=3)
ms.DA.classIV_F <- mshape(c.classIV_F)- mshape(d.classIV_F)
DA.classIV_F <- matrix(NA,41,1)
for(i in 1:nrow(mshape(c.classIV_F))){DA.classIV_F[i,]<-distanceS(mshape(c.classIV_F)[i,], mshape(d.classIV_F)[i,])}
DA.classIV_F
FA.classIV_F <- matrix(NA,41,14)
for(i in 1:14){for(j in 1:nrow(ms.DA.classIV_F)){FA.classIV_F[j,i]<-distanceS((c.classIV_F-d.classIV_F)[j,,i], ms.DA.classIV_F[j,])}}
FA.classIV_F


#############
## GROUP_V ##
#############

ind.classV_M <- c(1:42)
ind.classV_F <- c(1:40)
sample.c.classV_M <- sample.c.classV[,,-c(3,5:8,10,13,17:19,22:24,27:28,31:32,35:36,39:40,42,44:45,48,50,54:55,57:60,62:64,69:70,72,74,77)]
sample.c.classV_F <- sample.c.classV[,,c(3,5:8,10,13,17:19,22:24,27:28,31:32,35:36,39:40,42,44:45,48,50,54:55,57:60,62:64,69:70,72,74,77)]
landpairs.classV_M <- as.matrix(read.table("landpairs.txt",header=T));surfslide.classV_M <- as.matrix(read.table("surfslide.txt",header=T))
dat <- sample.c.classV_M;dat <- gpagen(dat, print.progress = T, curves= curveslide.classV, surfaces= surfslide.classV_M);size <- dat$Csize;dat <- dat$coords
ind <- ind.classV_M;landpairs <- landpairs.classV_M
n <- dim(dat)[3];k <- dim(dat)[2];p <- dim(dat)[1];nind <- nlevels(ind);spec.names <- dimnames(dat)[[3]]
npairs <- nrow(landpairs)
nl <- p - 2 * npairs
dat2 <- dat;dat2[landpairs[, 1], , ] <- dat[landpairs[, 2], , ];dat2[landpairs[, 2], , ] <- dat[landpairs[, 1], , ];dat2[, 1, ] <- dat2[, 1, ] * (-1)
dat <- array(c(dat, dat2), c(p, k, 2 * n))
ind <- factor(rep(ind, 2));side <- gl(2, n)
res <- gpagen(dat, print.progress = T)
dat <- res$coords
Ddat <- two.d.array(dat)
form <- Ddat ~ ind + side;form.cat <- c("ind", "reflection", "indXreflection", "Total")
gdf.dat.classV_M <- geomorph.data.frame(Ddat = Ddat, ind = ind, side = side)
proc.classV_M <- procD.lm(form, data = gdf.dat.classV_M, RRPP = T,seed = NULL, iter = 499, print.progress = T,effect.type = "F")
stat.classV_M <- anova(proc.classV_M, print.progress = FALSE, effect.type = "F")$table;stat.classV_M$Z[is.nan(stat.classV_M$Z)] <- NA
MS <- proc.classV_M$ANOVA$MS
RSS <- proc.classV_M$ANOVA$RSS
MSE <- RSS/matrix(proc.classV_M$ANOVA$df[nrow(RSS) + 1], nrow(RSS),ncol(RSS))
randstat.classV_M <- MS/MSE
rownames(stat.classV_M) <- form.cat
Dind <- model.matrix(~ind + 0, data = as.data.frame(gdf.dat.classV_M[-1]))
symm.var.classV_M <- arrayspecs(coef(lm.fit(Dind, Ddat)), p, k)
spec.names <- substr(dimnames(symm.var.classV_M)[[3]], start = 4,stop = nchar(dimnames(symm.var.classV_M)[[3]]));dimnames(symm.var.classV_M)[[3]] <- spec.names
Dside <- model.matrix(~(side:ind) + 0, data = as.data.frame(gdf.dat.classV_M[-1]))
mn.symm <- coef(lm.fit(Dside, Ddat))
nlind <- nlevels(ind);nlside <- nlevels(side)
indseq <- seq(nlside, (nlind * nlside), nlside)
asymm.var.classV_M <- mn.symm[indseq, ] - mn.symm[-indseq,]
mn.dat <- mshape(dat)
asymm.var.classV_M <- simplify2array(lapply(1:nlind, function(j) {t(matrix(asymm.var.classV_M[j, ], k, p)) + mn.dat}));dimnames(asymm.var.classV_M)[[3]] <- spec.names
DA <- arrayspecs(coef(.lm.fit(Dside, Ddat)), p, k)
k.classV_M <- DA
c.classV_M <- abind(k.classV_M[,,1],k.classV_M[,,3],k.classV_M[,,5],k.classV_M[,,7],k.classV_M[,,9],k.classV_M[,,11],k.classV_M[,,13],k.classV_M[,,15],k.classV_M[,,17],k.classV_M[,,19],k.classV_M[,,21],k.classV_M[,,23],k.classV_M[,,25],k.classV_M[,,27],k.classV_M[,,29],k.classV_M[,,31],k.classV_M[,,33],k.classV_M[,,35],k.classV_M[,,37],k.classV_M[,,39],k.classV_M[,,41],k.classV_M[,,43],k.classV_M[,,45],k.classV_M[,,47],k.classV_M[,,49],k.classV_M[,,51],k.classV_M[,,53],k.classV_M[,,55],k.classV_M[,,57],k.classV_M[,,59],k.classV_M[,,61],k.classV_M[,,63],k.classV_M[,,65],k.classV_M[,,67],k.classV_M[,,69],k.classV_M[,,71],k.classV_M[,,73],k.classV_M[,,75],k.classV_M[,,77],k.classV_M[,,79],k.classV_M[,,81],k.classV_M[,,83],along=3)
d.classV_M <- abind(k.classV_M[,,2],k.classV_M[,,4],k.classV_M[,,6],k.classV_M[,,8],k.classV_M[,,10],k.classV_M[,,12],k.classV_M[,,14],k.classV_M[,,16],k.classV_M[,,18],k.classV_M[,,20],k.classV_M[,,22],k.classV_M[,,24],k.classV_M[,,26],k.classV_M[,,28],k.classV_M[,,30],k.classV_M[,,32],k.classV_M[,,34],k.classV_M[,,36],k.classV_M[,,38],k.classV_M[,,40],k.classV_M[,,42],k.classV_M[,,44],k.classV_M[,,46],k.classV_M[,,48],k.classV_M[,,50],k.classV_M[,,52],k.classV_M[,,54],k.classV_M[,,56],k.classV_M[,,58],k.classV_M[,,60],k.classV_M[,,62],k.classV_M[,,64],k.classV_M[,,66],k.classV_M[,,68],k.classV_M[,,70],k.classV_M[,,72],k.classV_M[,,74],k.classV_M[,,76],k.classV_M[,,78],k.classV_M[,,80],k.classV_M[,,82],k.classV_M[,,84],along=3)
ms.DA.classV_M <- mshape(c.classV_M)- mshape(d.classV_M)
DA.classV_M <- matrix(NA,41,1)
for(i in 1:nrow(mshape(c.classV_M))){DA.classV_M[i,]<-distanceS(mshape(c.classV_M)[i,], mshape(d.classV_M)[i,])}
DA.classV_M
FA.classV_M <- matrix(NA,41,42)
for(i in 1:42){for(j in 1:nrow(ms.DA.classV_M)){FA.classV_M[j,i]<-distanceS((c.classV_M-d.classV_M)[j,,i], ms.DA.classV_M[j,])}}
FA.classV_M

landpairs.classV_F <- as.matrix(read.table("landpairs.txt",header=T));surfslide.classV_F <- as.matrix(read.table("surfslide.txt",header=T))
dat <- sample.c.classV_F;dat <- gpagen(dat, print.progress = T, curves= curveslide.classV, surfaces= surfslide.classV_F);size <- dat$Csize;dat <- dat$coords
ind <- ind.classV_F;landpairs <- landpairs.classV_F
n <- dim(dat)[3];k <- dim(dat)[2];p <- dim(dat)[1];nind <- nlevels(ind);spec.names <- dimnames(dat)[[3]]
npairs <- nrow(landpairs)
nl <- p - 2 * npairs
dat2 <- dat;dat2[landpairs[, 1], , ] <- dat[landpairs[, 2], , ];dat2[landpairs[, 2], , ] <- dat[landpairs[, 1], , ];dat2[, 1, ] <- dat2[, 1, ] * (-1)
dat <- array(c(dat, dat2), c(p, k, 2 * n))
ind <- factor(rep(ind, 2));side <- gl(2, n)
res <- gpagen(dat, print.progress = T)
dat <- res$coords
Ddat <- two.d.array(dat)
form <- Ddat ~ ind + side;form.cat <- c("ind", "reflection", "indXreflection", "Total")
gdf.dat.classV_F <- geomorph.data.frame(Ddat = Ddat, ind = ind, side = side)
proc.classV_F <- procD.lm(form, data = gdf.dat.classV_F, RRPP = T,seed = NULL, iter = 499, print.progress = T,effect.type = "F")
stat.classV_F <- anova(proc.classV_F, print.progress = FALSE, effect.type = "F")$table;stat.classV_F$Z[is.nan(stat.classV_F$Z)] <- NA
MS <- proc.classV_F$ANOVA$MS
RSS <- proc.classV_F$ANOVA$RSS
MSE <- RSS/matrix(proc.classV_F$ANOVA$df[nrow(RSS) + 1], nrow(RSS),ncol(RSS))
randstat.classV_F <- MS/MSE
rownames(stat.classV_F) <- form.cat
Dind <- model.matrix(~ind + 0, data = as.data.frame(gdf.dat.classV_F[-1]))
symm.var.classV_F <- arrayspecs(coef(lm.fit(Dind, Ddat)), p, k)
spec.names <- substr(dimnames(symm.var.classV_F)[[3]], start = 4,stop = nchar(dimnames(symm.var.classV_F)[[3]]));dimnames(symm.var.classV_F)[[3]] <- spec.names
Dside <- model.matrix(~(side:ind) + 0, data = as.data.frame(gdf.dat.classV_F[-1]))
mn.symm <- coef(lm.fit(Dside, Ddat))
nlind <- nlevels(ind);nlside <- nlevels(side)
indseq <- seq(nlside, (nlind * nlside), nlside)
asymm.var.classV_F <- mn.symm[indseq, ] - mn.symm[-indseq,]
mn.dat <- mshape(dat)
asymm.var.classV_F <- simplify2array(lapply(1:nlind, function(j) {t(matrix(asymm.var.classV_F[j, ], k, p)) + mn.dat}));dimnames(asymm.var.classV_F)[[3]] <- spec.names
DA <- arrayspecs(coef(.lm.fit(Dside, Ddat)), p, k)
k.classV_F <- DA
c.classV_F <- abind(k.classV_F[,,1],k.classV_F[,,3],k.classV_F[,,5],k.classV_F[,,7],k.classV_F[,,9],k.classV_F[,,11],k.classV_F[,,13],k.classV_F[,,15],k.classV_F[,,17],k.classV_F[,,19],k.classV_F[,,21],k.classV_F[,,23],k.classV_F[,,25],k.classV_F[,,27],k.classV_F[,,29],k.classV_F[,,31],k.classV_F[,,33],k.classV_F[,,35],k.classV_F[,,37],k.classV_F[,,39],k.classV_F[,,41],k.classV_F[,,43],k.classV_F[,,45],k.classV_F[,,47],k.classV_F[,,49],k.classV_F[,,51],k.classV_F[,,53],k.classV_F[,,55],k.classV_F[,,57],k.classV_F[,,59],k.classV_F[,,61],k.classV_F[,,63],k.classV_F[,,65],k.classV_F[,,67],k.classV_F[,,69],k.classV_F[,,71],k.classV_F[,,73],k.classV_F[,,75],k.classV_F[,,77],k.classV_F[,,79],along=3)
d.classV_F <- abind(k.classV_F[,,2],k.classV_F[,,4],k.classV_F[,,6],k.classV_F[,,8],k.classV_F[,,10],k.classV_F[,,12],k.classV_F[,,14],k.classV_F[,,16],k.classV_F[,,18],k.classV_F[,,20],k.classV_F[,,22],k.classV_F[,,24],k.classV_F[,,26],k.classV_F[,,28],k.classV_F[,,30],k.classV_F[,,32],k.classV_F[,,34],k.classV_F[,,36],k.classV_F[,,38],k.classV_F[,,40],k.classV_F[,,42],k.classV_F[,,44],k.classV_F[,,46],k.classV_F[,,48],k.classV_F[,,50],k.classV_F[,,52],k.classV_F[,,54],k.classV_F[,,56],k.classV_F[,,58],k.classV_F[,,60],k.classV_F[,,62],k.classV_F[,,64],k.classV_F[,,66],k.classV_F[,,68],k.classV_F[,,70],k.classV_F[,,72],k.classV_F[,,74],k.classV_F[,,76],k.classV_F[,,78],k.classV_F[,,80],along=3)
ms.DA.classV_F <- mshape(c.classV_F)- mshape(d.classV_F)
DA.classV_F <- matrix(NA,41,1)
for(i in 1:nrow(mshape(c.classV_F))){DA.classV_F[i,]<-distanceS(mshape(c.classV_F)[i,], mshape(d.classV_F)[i,])}
DA.classV_F
FA.classV_F <- matrix(NA,41,40)
for(i in 1:40){for(j in 1:nrow(ms.DA.classV_F)){FA.classV_F[j,i]<-distanceS((c.classV_F-d.classV_F)[j,,i], ms.DA.classV_F[j,])}}
FA.classV_F


##############
## GROUP_VI ##
##############

ind.classVI_M <- c(1:19)
ind.classVI_F <- c(1:26)
sample.c.classVI_M <- sample.c.classVI[,,-c(1:4,6:7,9,15:16,21,23,25:26,28:30,32:38,40:41,44)]
sample.c.classVI_F <- sample.c.classVI[,,c(1:4,6:7,9,15:16,21,23,25:26,28:30,32:38,40:41,44)]
landpairs.classVI_M <- as.matrix(read.table("landpairs.txt",header=T));surfslide.classVI_M <- as.matrix(read.table("surfslide.txt",header=T))
dat <- sample.c.classVI_M;dat <- gpagen(dat, print.progress = T, curves= curveslide.classVI, surfaces= surfslide.classVI_M);size <- dat$Csize;dat <- dat$coords
ind <- ind.classVI_M;landpairs <- landpairs.classVI_M
n <- dim(dat)[3];k <- dim(dat)[2];p <- dim(dat)[1];nind <- nlevels(ind);spec.names <- dimnames(dat)[[3]]
npairs <- nrow(landpairs)
nl <- p - 2 * npairs
dat2 <- dat;dat2[landpairs[, 1], , ] <- dat[landpairs[, 2], , ];dat2[landpairs[, 2], , ] <- dat[landpairs[, 1], , ];dat2[, 1, ] <- dat2[, 1, ] * (-1)
dat <- array(c(dat, dat2), c(p, k, 2 * n))
ind <- factor(rep(ind, 2));side <- gl(2, n)
res <- gpagen(dat, print.progress = T)
dat <- res$coords
Ddat <- two.d.array(dat)
form <- Ddat ~ ind + side;form.cat <- c("ind", "reflection", "indXreflection", "Total")
gdf.dat.classVI_M <- geomorph.data.frame(Ddat = Ddat, ind = ind, side = side)
proc.classVI_M <- procD.lm(form, data = gdf.dat.classVI_M, RRPP = T,seed = NULL, iter = 499, print.progress = T,effect.type = "F")
stat.classVI_M <- anova(proc.classVI_M, print.progress = FALSE, effect.type = "F")$table;stat.classVI_M$Z[is.nan(stat.classVI_M$Z)] <- NA
MS <- proc.classVI_M$ANOVA$MS
RSS <- proc.classVI_M$ANOVA$RSS
MSE <- RSS/matrix(proc.classVI_M$ANOVA$df[nrow(RSS) + 1], nrow(RSS),ncol(RSS))
randstat.classVI_M <- MS/MSE
rownames(stat.classVI_M) <- form.cat
Dind <- model.matrix(~ind + 0, data = as.data.frame(gdf.dat.classVI_M[-1]))
symm.var.classVI_M <- arrayspecs(coef(lm.fit(Dind, Ddat)), p, k)
spec.names <- substr(dimnames(symm.var.classVI_M)[[3]], start = 4,stop = nchar(dimnames(symm.var.classVI_M)[[3]]));dimnames(symm.var.classVI_M)[[3]] <- spec.names
Dside <- model.matrix(~(side:ind) + 0, data = as.data.frame(gdf.dat.classVI_M[-1]))
mn.symm <- coef(lm.fit(Dside, Ddat))
nlind <- nlevels(ind);nlside <- nlevels(side)
indseq <- seq(nlside, (nlind * nlside), nlside)
asymm.var.classVI_M <- mn.symm[indseq, ] - mn.symm[-indseq,]
mn.dat <- mshape(dat)
asymm.var.classVI_M <- simplify2array(lapply(1:nlind, function(j) {t(matrix(asymm.var.classVI_M[j, ], k, p)) + mn.dat}));dimnames(asymm.var.classVI_M)[[3]] <- spec.names
DA <- arrayspecs(coef(.lm.fit(Dside, Ddat)), p, k)
k.classVI_M <- DA
c.classVI_M <- abind(k.classVI_M[,,1],k.classVI_M[,,3],k.classVI_M[,,5],k.classVI_M[,,7],k.classVI_M[,,9],k.classVI_M[,,11],k.classVI_M[,,13],k.classVI_M[,,15],k.classVI_M[,,17],k.classVI_M[,,19],k.classVI_M[,,21],k.classVI_M[,,23],k.classVI_M[,,25],k.classVI_M[,,27],k.classVI_M[,,29],k.classVI_M[,,31],k.classVI_M[,,33],k.classVI_M[,,35],k.classVI_M[,,37],along=3)
d.classVI_M <- abind(k.classVI_M[,,2],k.classVI_M[,,4],k.classVI_M[,,6],k.classVI_M[,,8],k.classVI_M[,,10],k.classVI_M[,,12],k.classVI_M[,,14],k.classVI_M[,,16],k.classVI_M[,,18],k.classVI_M[,,20],k.classVI_M[,,22],k.classVI_M[,,24],k.classVI_M[,,26],k.classVI_M[,,28],k.classVI_M[,,30],k.classVI_M[,,32],k.classVI_M[,,34],k.classVI_M[,,36],k.classVI_M[,,38],along=3)
ms.DA.classVI_M <- mshape(c.classVI_M)- mshape(d.classVI_M)
DA.classVI_M <- matrix(NA,41,1)
for(i in 1:nrow(mshape(c.classVI_M))){DA.classVI_M[i,]<-distanceS(mshape(c.classVI_M)[i,], mshape(d.classVI_M)[i,])}
DA.classVI_M
FA.classVI_M <- matrix(NA,41,19)
for(i in 1:19){for(j in 1:nrow(ms.DA.classVI_M)){FA.classVI_M[j,i]<-distanceS((c.classVI_M-d.classVI_M)[j,,i], ms.DA.classVI_M[j,])}}
FA.classVI_M

landpairs.classVI_F <- as.matrix(read.table("landpairs.txt",header=T));surfslide.classVI_F <- as.matrix(read.table("surfslide.txt",header=T))
dat <- sample.c.classVI_F;dat <- gpagen(dat, print.progress = T, curves= curveslide.classVI, surfaces= surfslide.classVI_F);size <- dat$Csize;dat <- dat$coords
ind <- ind.classVI_F;landpairs <- landpairs.classVI_F
n <- dim(dat)[3];k <- dim(dat)[2];p <- dim(dat)[1];nind <- nlevels(ind);spec.names <- dimnames(dat)[[3]]
npairs <- nrow(landpairs)
nl <- p - 2 * npairs
dat2 <- dat;dat2[landpairs[, 1], , ] <- dat[landpairs[, 2], , ];dat2[landpairs[, 2], , ] <- dat[landpairs[, 1], , ];dat2[, 1, ] <- dat2[, 1, ] * (-1)
dat <- array(c(dat, dat2), c(p, k, 2 * n))
ind <- factor(rep(ind, 2));side <- gl(2, n)
res <- gpagen(dat, print.progress = T)
dat <- res$coords
Ddat <- two.d.array(dat)
form <- Ddat ~ ind + side;form.cat <- c("ind", "reflection", "indXreflection", "Total")
gdf.dat.classVI_F <- geomorph.data.frame(Ddat = Ddat, ind = ind, side = side)
proc.classVI_F <- procD.lm(form, data = gdf.dat.classVI_F, RRPP = T,seed = NULL, iter = 499, print.progress = T,effect.type = "F")
stat.classVI_F <- anova(proc.classVI_F, print.progress = FALSE, effect.type = "F")$table;stat.classVI_F$Z[is.nan(stat.classVI_F$Z)] <- NA
MS <- proc.classVI_F$ANOVA$MS
RSS <- proc.classVI_F$ANOVA$RSS
MSE <- RSS/matrix(proc.classVI_F$ANOVA$df[nrow(RSS) + 1], nrow(RSS),ncol(RSS))
randstat.classVI_F <- MS/MSE
rownames(stat.classVI_F) <- form.cat
Dind <- model.matrix(~ind + 0, data = as.data.frame(gdf.dat.classVI_F[-1]))
symm.var.classVI_F <- arrayspecs(coef(lm.fit(Dind, Ddat)), p, k)
spec.names <- substr(dimnames(symm.var.classVI_F)[[3]], start = 4,stop = nchar(dimnames(symm.var.classVI_F)[[3]]));dimnames(symm.var.classVI_F)[[3]] <- spec.names
Dside <- model.matrix(~(side:ind) + 0, data = as.data.frame(gdf.dat.classVI_F[-1]))
mn.symm <- coef(lm.fit(Dside, Ddat))
nlind <- nlevels(ind);nlside <- nlevels(side)
indseq <- seq(nlside, (nlind * nlside), nlside)
asymm.var.classVI_F <- mn.symm[indseq, ] - mn.symm[-indseq,]
mn.dat <- mshape(dat)
asymm.var.classVI_F <- simplify2array(lapply(1:nlind, function(j) {t(matrix(asymm.var.classVI_F[j, ], k, p)) + mn.dat}));dimnames(asymm.var.classVI_F)[[3]] <- spec.names
DA <- arrayspecs(coef(.lm.fit(Dside, Ddat)), p, k)
k.classVI_F <- DA
c.classVI_F <- abind(k.classVI_F[,,1],k.classVI_F[,,3],k.classVI_F[,,5],k.classVI_F[,,7],k.classVI_F[,,9],k.classVI_F[,,11],k.classVI_F[,,13],k.classVI_F[,,15],k.classVI_F[,,17],k.classVI_F[,,19],k.classVI_F[,,21],k.classVI_F[,,23],k.classVI_F[,,25],k.classVI_F[,,27],k.classVI_F[,,29],k.classVI_F[,,31],k.classVI_F[,,33],k.classVI_F[,,35],k.classVI_F[,,37],k.classVI_F[,,39],k.classVI_F[,,41],k.classVI_F[,,43],k.classVI_F[,,45],k.classVI_F[,,47],k.classVI_F[,,49],k.classVI_F[,,51],along=3)
d.classVI_F <- abind(k.classVI_F[,,2],k.classVI_F[,,4],k.classVI_F[,,6],k.classVI_F[,,8],k.classVI_F[,,10],k.classVI_F[,,12],k.classVI_F[,,14],k.classVI_F[,,16],k.classVI_F[,,18],k.classVI_F[,,20],k.classVI_F[,,22],k.classVI_F[,,24],k.classVI_F[,,26],k.classVI_F[,,28],k.classVI_F[,,30],k.classVI_F[,,32],k.classVI_F[,,34],k.classVI_F[,,36],k.classVI_F[,,38],k.classVI_F[,,40],k.classVI_F[,,42],k.classVI_F[,,44],k.classVI_F[,,46],k.classVI_F[,,48],k.classVI_F[,,50],k.classVI_F[,,52],along=3)
ms.DA.classVI_F <- mshape(c.classVI_F)- mshape(d.classVI_F)
DA.classVI_F <- matrix(NA,41,1)
for(i in 1:nrow(mshape(c.classVI_F))){DA.classVI_F[i,]<-distanceS(mshape(c.classVI_F)[i,], mshape(d.classVI_F)[i,])}
DA.classVI_F
FA.classVI_F <- matrix(NA,41,26)
for(i in 1:26){for(j in 1:nrow(ms.DA.classVI_F)){FA.classVI_F[j,i]<-distanceS((c.classVI_F-d.classVI_F)[j,,i], ms.DA.classVI_F[j,])}}
FA.classVI_F



############## plot ############## 

###############
## Figure 2A ##
###############

plot_colors <- c("red", "black", "forestgreen", "blue", "mediumorchid2", "yellow")
plot(DA.classI, type="n", pch=16, col=plot_colors[1], ylim=c(0, 0.016), axes=FALSE, ann=FALSE)
axis(1, at=1:41, lab=c(1:41))
axis(2)
box()
lines(DA.classI, lty=1, col=plot_colors[1], lwd=3)
lines(DA.classII, lty=1, col=plot_colors[2], lwd=3)
lines(DA.classIII, lty=1, col=plot_colors[3], lwd=3)
lines(DA.classIV, lty=1, col=plot_colors[4], lwd=3)
lines(DA.classV, lty=1, col=plot_colors[5], lwd=3)
lines(DA.classVI, lty=1, col=plot_colors[6], lwd=3)
title(xlab= "landmarks", col.lab=rgb(0,0.5,0))
title(ylab= "DA", col.lab=rgb(0,0.5,0))
legend("topright", legend = c("ClassI", "ClassII", "ClassIII", "ClassIV", "ClassV", "ClassVI"), col = c("red", "black", "forestgreen", "blue", "mediumorchid2", "yellow"), pch = c(16,16,16,16,16,16), bty = "n", pt.cex = 1.3, cex = 1, text.col = "black", horiz = FALSE, inset = c(-0, 0))



###############
## Figure 2B ##
###############

DA.class <- abind(DA.classI,DA.classII,DA.classIII,DA.classIV,DA.classV,DA.classVI,along=3)
DA.class2<-array(NA,c(dim(DA.class)[3],dim(DA.class)[3],dim(DA.class)[1]))
for(i in 1:dim(DA.class)[3]) {for(j in 1:dim(DA.class)[3]) {for(k in 1:dim(DA.class)[1]) {DA.class2[j,i,k] <- DA.class[k,,i]-DA.class[k,,j]}}}
DAplot2.class<-cbind(as.vector(as.dist(DA.class2[,,1])),as.vector(as.dist(DA.class2[,,2])),as.vector(as.dist(DA.class2[,,3])),as.vector(as.dist(DA.class2[,,4])),as.vector(as.dist(DA.class2[,,5])),as.vector(as.dist(DA.class2[,,6])),as.vector(as.dist(DA.class2[,,7])),as.vector(as.dist(DA.class2[,,8])),as.vector(as.dist(DA.class2[,,9])),as.vector(as.dist(DA.class2[,,10])),as.vector(as.dist(DA.class2[,,11])),as.vector(as.dist(DA.class2[,,12])),as.vector(as.dist(DA.class2[,,13])),as.vector(as.dist(DA.class2[,,14])),as.vector(as.dist(DA.class2[,,15])),as.vector(as.dist(DA.class2[,,16])),as.vector(as.dist(DA.class2[,,17])),as.vector(as.dist(DA.class2[,,18])),as.vector(as.dist(DA.class2[,,19])),as.vector(as.dist(DA.class2[,,20])),as.vector(as.dist(DA.class2[,,21])),as.vector(as.dist(DA.class2[,,22])),as.vector(as.dist(DA.class2[,,23])),as.vector(as.dist(DA.class2[,,24])),as.vector(as.dist(DA.class2[,,25])),as.vector(as.dist(DA.class2[,,26])),as.vector(as.dist(DA.class2[,,27])),as.vector(as.dist(DA.class2[,,28])),as.vector(as.dist(DA.class2[,,29])),as.vector(as.dist(DA.class2[,,30])),as.vector(as.dist(DA.class2[,,31])),as.vector(as.dist(DA.class2[,,32])),as.vector(as.dist(DA.class2[,,33])),as.vector(as.dist(DA.class2[,,34])),as.vector(as.dist(DA.class2[,,35])),as.vector(as.dist(DA.class2[,,36])),as.vector(as.dist(DA.class2[,,37])),as.vector(as.dist(DA.class2[,,38])),as.vector(as.dist(DA.class2[,,39])),as.vector(as.dist(DA.class2[,,40])),as.vector(as.dist(DA.class2[,,41])))
IQR_DA.class2 <- vector()
for (i in 1:41){IQR_DA.class2<- c(IQR_DA.class2,IQR(DAplot2.class[,i]))}
summary(IQR_DA.class2)
boxplot(DAplot2.class, col=ifelse(IQR_DA.class2>=0.0039, "forestgreen", ifelse(IQR_DA.class2<=0.0025, "blue", "grey80")))
axis(2)
box()
legend("topright", legend = c("IQR>=0.0039", "IQR<=0.0025"), col = c("forestgreen", "blue"), pch = c(16,16), bty = "n", pt.cex = 1.3, cex = 1, text.col = "black", horiz = FALSE, inset = c(-0, 0))



###############
## Figure 2C ##
###############

DAplot3.class<-abind(DA.classI-DA.classII,
DA.classII-DA.classIII,
DA.classIII-DA.classIV,
DA.classIV-DA.classV,
DA.classV-DA.classVI)
cols <- brewer.pal(9, "Blues")
barplot((t(prop.table(abs(DAplot3.class),1))),col=c(col=cols[4:8]),names.arg=c(1:41))
par(fig = c(0, 1, 0, 1), oma = c(0, 0, 0, 0), mar = c(0, 0, 0, 0), new = TRUE)
plot(0, 0, type = "n", bty = "n", xaxt = "n", yaxt = "n")
legend("bottom", c("DA.cI-DA.cII", "DA.cII-DA.cIII", "DA.cIII-DA.cIV", "DA.cIV-DA.cV", "DA.cV-DA.cVI"), xpd = TRUE, horiz = TRUE, inset = c(0, 0), bty = "n", pch = c(16,16,16,16,16), col = cols[4:8], cex = 1)



##############
## Figure 4 ##
##############

par(mfrow=c(7, 1),mgp=c(3,1,0), mar=c(1.1, 1.9, 1.1, 1.9),oma=c(4,1,3,1))
plot(rowMeans(FA.classI), type="n", pch=16, ylim=c(0.002,0.028), axes=FALSE, ann=FALSE)
axis(1, at=1:41, lab=c(1:41))
axis(2)
lines (rowMeans(FA.classI),lwd=3,col="red")
rowMeans(FA.classI)+(apply(FA.classI, 1, std.error)*1.96)
rowMeans(FA.classI)-(apply(FA.classI, 1, std.error)*1.96)
polycoordx <- c(1:41, 41:1)
polycoordy <- c(rowMeans(FA.classI)+(apply(FA.classI, 1, std.error)*1.96), rev(rowMeans(FA.classI)-(apply(FA.classI, 1, std.error)*1.96)))
polygon(x=polycoordx, y=polycoordy, col=rgb(1,0,0,0.5), lwd=1, border=NA, density=50)
plot(rowMeans(FA.classII), type="n", pch=16, ylim=c(0.002,0.028), axes=FALSE, ann=FALSE)
axis(1, at=1:41, lab=c(1:41))
axis(2)
lines (rowMeans(FA.classII),lwd=3,col="black")
rowMeans(FA.classII)+(apply(FA.classII, 1, std.error)*1.96)
rowMeans(FA.classII)-(apply(FA.classII, 1, std.error)*1.96)
polycoordx <- c(1:41, 41:1)
polycoordy <- c(rowMeans(FA.classII)+(apply(FA.classII, 1, std.error)*1.96), rev(rowMeans(FA.classII)-(apply(FA.classII, 1, std.error)*1.96)))
polygon(x=polycoordx, y=polycoordy, col=c("red"), lwd=1, border=NA, density=50)
plot(rowMeans(FA.classIII), type="n", pch=16, ylim=c(0.002,0.028), axes=FALSE, ann=FALSE)
axis(1, at=1:41, lab=c(1:41))
axis(2)
lines (rowMeans(FA.classIII),lwd=3,col="forestgreen")
rowMeans(FA.classIII)+(apply(FA.classIII, 1, std.error)*1.96)
rowMeans(FA.classIII)-(apply(FA.classIII, 1, std.error)*1.96)
polycoordx <- c(1:41, 41:1)
polycoordy <- c(rowMeans(FA.classIII)+(apply(FA.classIII, 1, std.error)*1.96), rev(rowMeans(FA.classIII)-(apply(FA.classIII, 1, std.error)*1.96)))
polygon(x=polycoordx, y=polycoordy, col=c("red"), lwd=1, border=NA, density=50)
plot(rowMeans(FA.classIV), type="n", pch=16, ylim=c(0.002,0.028), axes=FALSE, ann=FALSE)
axis(1, at=1:41, lab=c(1:41))
axis(2)
lines (rowMeans(FA.classIV),lwd=3,col="blue")
rowMeans(FA.classIV)+(apply(FA.classIV, 1, std.error)*1.96)
rowMeans(FA.classIV)-(apply(FA.classIV, 1, std.error)*1.96)
polycoordx <- c(1:41, 41:1)
polycoordy <- c(rowMeans(FA.classIV)+(apply(FA.classIV, 1, std.error)*1.96), rev(rowMeans(FA.classIV)-(apply(FA.classIV, 1, std.error)*1.96)))
polygon(x=polycoordx, y=polycoordy, col=c("red"), lwd=1, border=NA, density=50)
plot(rowMeans(FA.classV), type="n", pch=16, ylim=c(0.002,0.028), axes=FALSE, ann=FALSE)
axis(1, at=1:41, lab=c(1:41))
axis(2)
lines (rowMeans(FA.classV),lwd=3,col="mediumorchid2")
rowMeans(FA.classV)+(apply(FA.classV, 1, std.error)*1.96)
rowMeans(FA.classV)-(apply(FA.classV, 1, std.error)*1.96)
polycoordx <- c(1:41, 41:1)
polycoordy <- c(rowMeans(FA.classV)+(apply(FA.classV, 1, std.error)*1.96), rev(rowMeans(FA.classV)-(apply(FA.classV, 1, std.error)*1.96)))
polygon(x=polycoordx, y=polycoordy, col=c("red"), lwd=1, border=NA, density=50)
plot(rowMeans(FA.classVI), type="n", pch=16, ylim=c(0.002,0.028), axes=FALSE, ann=FALSE)
axis(1, at=1:41, lab=c(1:41))
axis(2)
lines (rowMeans(FA.classVI),lwd=3,col="yellow")
rowMeans(FA.classVI)+(apply(FA.classVI, 1, std.error)*1.96)
rowMeans(FA.classVI)-(apply(FA.classVI, 1, std.error)*1.96)
polycoordx <- c(1:41, 41:1)
polycoordy <- c(rowMeans(FA.classVI)+(apply(FA.classVI, 1, std.error)*1.96), rev(rowMeans(FA.classVI)-(apply(FA.classVI, 1, std.error)*1.96)))
polygon(x=polycoordx, y=polycoordy, col=c("red"), lwd=1, border=NA, density=50)



######################
## Figure 3 boxplot ##
######################

classIV.test.DA<-rbind(t(DA.classIV_M),t(DA.classIV_F))
classV.test.DA<-rbind(t(DA.classV_M),t(DA.classV_F))
classVI.test.DA<-rbind(t(DA.classVI_M),t(DA.classVI_F))
sex.test.fact.DA<-as.factor(c(rep("M",1),rep("F",1)))
par(mfrow=c(3, 1),mgp=c(3,1,0), mar=c(1.5, 1.9, 0.9, 1.9),oma=c(4,14,4,14))
boxplot(classIV.test.DA~sex.test.fact.DA,col=(c("blue","red")),ylim=c(-0.004, 0.017))
boxplot(classV.test.DA~sex.test.fact.DA,col=(c("blue","red")),ylim=c(-0.004, 0.017))
boxplot(classVI.test.DA~sex.test.fact.DA,col=(c("blue","red")),ylim=c(-0.004, 0.017))



########################
## Figure 3 line plot ##
########################

par(mfrow=c(3, 1),mgp=c(3,1,0), mar=c(1.1, 1.9, 1.1, 1.9),oma=c(4,1,3,1))
plot_colors <- c("red", "blue")
plot(DA.classIV_M, type="n", pch=16, col=plot_colors[1], ylim=c(0, 0.016), axes=FALSE, ann=FALSE)
axis(1, at=1:41, lab=c(1:41))
axis(2)
box()
lines(DA.classIV_M, lty=1, col=plot_colors[1], lwd=3)
lines(DA.classIV_F, lty=1, col=plot_colors[2], lwd=3)
title(xlab= "landmarks", col.lab=rgb(0,0.5,0))
title(ylab= "DA", col.lab=rgb(0,0.5,0))
legend("topright", legend = c("ClassIV_M", "ClassIV_F"), col = c("red", "blue"), pch = c(16,16), bty = "n", pt.cex = 1.3, cex = 1, text.col = "black", horiz = FALSE, inset = c(-0, 0))
plot_colors <- c("red", "blue")
plot(DA.classV_M, type="n", pch=16, col=plot_colors[1], ylim=c(0, 0.016), axes=FALSE, ann=FALSE)
axis(1, at=1:41, lab=c(1:41))
axis(2)
box()
lines(DA.classV_M, lty=1, col=plot_colors[1], lwd=3)
lines(DA.classV_F, lty=1, col=plot_colors[2], lwd=3)
title(xlab= "landmarks", col.lab=rgb(0,0.5,0))
title(ylab= "DA", col.lab=rgb(0,0.5,0))
legend("topright", legend = c("ClassV_M", "ClassV_F"), col = c("red", "blue"), pch = c(16,16), bty = "n", pt.cex = 1.3, cex = 1, text.col = "black", horiz = FALSE, inset = c(-0, 0))
plot_colors <- c("red", "blue")
plot(DA.classV_M, type="n", pch=16, col=plot_colors[1], ylim=c(0, 0.016), axes=FALSE, ann=FALSE)
axis(1, at=1:41, lab=c(1:41))
axis(2)
box()
lines(DA.classVI_M, lty=1, col=plot_colors[1], lwd=3)
lines(DA.classVI_F, lty=1, col=plot_colors[2], lwd=3)
title(xlab= "landmarks", col.lab=rgb(0,0.5,0))
title(ylab= "DA", col.lab=rgb(0,0.5,0))
legend("topright", legend = c("ClassVI_M", "ClassVI_F"), col = c("red", "blue"), pch = c(16,16), bty = "n", pt.cex = 1.3, cex = 1, text.col = "black", horiz = FALSE, inset = c(-0, 0))



######################
## Figure 5 boxplot ##
######################

classIV.test.FA<-rbind(t(FA.classIV_M),t(FA.classIV_F))
classV.test.FA<-rbind(t(FA.classV_M),t(FA.classV_F))
classVI.test.FA<-rbind(t(FA.classVI_M),t(FA.classVI_F))
classIV.sex.fact.FA<-as.factor(c(rep("M",11),rep("F",14)))
classV.sex.fact.FA<-as.factor(c(rep("M",42),rep("F",40)))
classVI.sex.fact.FA<-as.factor(c(rep("M",19),rep("F",26)))
par(mfrow=c(3, 1),mgp=c(3,1,0), mar=c(1.5, 1.9, 0.9, 1.9),oma=c(4,14,4,14))
boxplot(classIV.test.FA~classIV.sex.fact.FA,col=(c("blue","red")),ylim=c(-0.005, 0.06))
boxplot(classV.test.FA~classV.sex.fact.FA,col=(c("blue","red")),ylim=c(-0.005, 0.06))
boxplot(classVI.test.FA~classVI.sex.fact.FA,col=(c("blue","red")),ylim=c(-0.005, 0.06))



##########################################
## Figure 5 line plot plus CI envelopes ##
##########################################

par(mfrow=c(7, 1),mgp=c(3,1,0), mar=c(1.1, 1.9, 1.1, 1.9),oma=c(4,1,3,1))
plot(rowMeans(FA.classIV_M), type="n", pch=16, ylim=c(0.002,0.028), axes=FALSE, ann=FALSE)
axis(1, at=1:41, lab=c(1:41))
axis(2)
lines (rowMeans(FA.classIV_M),lwd=3,col="red")
rowMeans(FA.classIV_M)+(apply(FA.classIV_M, 1, std.error)*1.96)
rowMeans(FA.classIV_M)-(apply(FA.classIV_M, 1, std.error)*1.96)
polycoordx <- c(1:41, 41:1)
polycoordy <- c(rowMeans(FA.classIV_M)+(apply(FA.classIV_M, 1, std.error)*1.96), rev(rowMeans(FA.classIV_M)-(apply(FA.classIV_M, 1, std.error)*1.96)))
polygon(x=polycoordx, y=polycoordy, col=rgb(1,0,0,0.5), lwd=1, border=NA, density=50)
plot(rowMeans(FA.classIV_F), type="n", pch=16, ylim=c(0.002,0.028), axes=FALSE, ann=FALSE)
axis(1, at=1:41, lab=c(1:41))
axis(2)
lines (rowMeans(FA.classIV_F),lwd=3,col="blue")
rowMeans(FA.classIV_F)+(apply(FA.classIV_F, 1, std.error)*1.96)
rowMeans(FA.classIV_F)-(apply(FA.classIV_F, 1, std.error)*1.96)
polycoordx <- c(1:41, 41:1)
polycoordy <- c(rowMeans(FA.classIV_F)+(apply(FA.classIV_F, 1, std.error)*1.96), rev(rowMeans(FA.classIV_F)-(apply(FA.classIV_F, 1, std.error)*1.96)))
polygon(x=polycoordx, y=polycoordy, col=c("red"), lwd=1, border=NA, density=50)
plot(rowMeans(FA.classV_M), type="n", pch=16, ylim=c(0.002,0.028), axes=FALSE, ann=FALSE)
axis(1, at=1:41, lab=c(1:41))
axis(2)
lines (rowMeans(FA.classV_M),lwd=3,col="red")
rowMeans(FA.classV_M)+(apply(FA.classV_M, 1, std.error)*1.96)
rowMeans(FA.classV_M)-(apply(FA.classV_M, 1, std.error)*1.96)
polycoordx <- c(1:41, 41:1)
polycoordy <- c(rowMeans(FA.classV_M)+(apply(FA.classV_M, 1, std.error)*1.96), rev(rowMeans(FA.classV_M)-(apply(FA.classV_M, 1, std.error)*1.96)))
polygon(x=polycoordx, y=polycoordy, col=c("red"), lwd=1, border=NA, density=50)
plot(rowMeans(FA.classV_F), type="n", pch=16, ylim=c(0.002,0.028), axes=FALSE, ann=FALSE)
axis(1, at=1:41, lab=c(1:41))
axis(2)
lines (rowMeans(FA.classV_F),lwd=3,col="blue")
rowMeans(FA.classV_F)+(apply(FA.classV_F, 1, std.error)*1.96)
rowMeans(FA.classV_F)-(apply(FA.classV_F, 1, std.error)*1.96)
polycoordx <- c(1:41, 41:1)
polycoordy <- c(rowMeans(FA.classV_F)+(apply(FA.classV_F, 1, std.error)*1.96), rev(rowMeans(FA.classV_F)-(apply(FA.classV_F, 1, std.error)*1.96)))
polygon(x=polycoordx, y=polycoordy, col=c("red"), lwd=1, border=NA, density=50)
plot(rowMeans(FA.classVI_M), type="n", pch=16, ylim=c(0.002,0.028), axes=FALSE, ann=FALSE)
axis(1, at=1:41, lab=c(1:41))
axis(2)
lines (rowMeans(FA.classVI_M),lwd=3,col="red")
rowMeans(FA.classVI_M)+(apply(FA.classVI_M, 1, std.error)*1.96)
rowMeans(FA.classVI_M)-(apply(FA.classVI_M, 1, std.error)*1.96)
polycoordx <- c(1:41, 41:1)
polycoordy <- c(rowMeans(FA.classVI_M)+(apply(FA.classVI_M, 1, std.error)*1.96), rev(rowMeans(FA.classVI_M)-(apply(FA.classVI_M, 1, std.error)*1.96)))
polygon(x=polycoordx, y=polycoordy, col=c("red"), lwd=1, border=NA, density=50)
plot(rowMeans(FA.classVI_F), type="n", pch=16, ylim=c(0.002,0.028), axes=FALSE, ann=FALSE)
axis(1, at=1:41, lab=c(1:41))
axis(2)
lines (rowMeans(FA.classVI_F),lwd=3,col="blue")
rowMeans(FA.classVI_F)+(apply(FA.classVI_F, 1, std.error)*1.96)
rowMeans(FA.classVI_F)-(apply(FA.classVI_F, 1, std.error)*1.96)
polycoordx <- c(1:41, 41:1)
polycoordy <- c(rowMeans(FA.classVI_F)+(apply(FA.classVI_F, 1, std.error)*1.96), rev(rowMeans(FA.classVI_F)-(apply(FA.classVI_F, 1, std.error)*1.96)))
polygon(x=polycoordx, y=polycoordy, col=c("red"), lwd=1, border=NA, density=50)



#############################################################
############# Statistical analysis ##########################
#############################################################




## DA_between groups diff_Tukey post-hoc ##
###########################################

seq.DA <-rbind(DA.classI,DA.classII,DA.classIII,DA.classIV,DA.classV,DA.classVI)
class.fact.DA <-as.factor(c(rep("ClassI",41), rep("ClassII",41), rep("ClassIII",41), rep("ClassIV",41), rep("ClassV",41),rep("ClassVI",41)))
bgd.DA <- aov(seq.DA~class.fact.DA)
summary(bgd.DA)
anova(procD.lm(seq.DA~class.fact.DA), print.progress = FALSE, effect.type = "F")$table
Tph.DA <- TukeyHSD(bgd.DA)
Tph.DA



## DA_Spearman ##
#################

DA.tot <-abind(DA.classI,DA.classII,DA.classIII,DA.classIV,DA.classV,DA.classVI)
cor(DA.tot, method = 'spearman', use = 'pairwise.complete.obs')[1,-1]
cor(DA.tot, method = 'spearman', use = 'pairwise.complete.obs')[2,-2]
cor(DA.tot, method = 'spearman', use = 'pairwise.complete.obs')[3,-3]
cor(DA.tot, method = 'spearman', use = 'pairwise.complete.obs')[4,-4]
cor(DA.tot, method = 'spearman', use = 'pairwise.complete.obs')[5,-5]
cor(DA.tot, method = 'spearman', use = 'pairwise.complete.obs')[6,-6]



## DA_KW_Dunn Test ##
#####################

DA.kwd <-as.matrix(read.table("DA_tot.txt"))
DA.kwd <-as.data.frame(t(DA.kwd))
allDA.kwd <-data.frame(a=unlist(DA.kwd, use.names = FALSE))
class.DAkwd <- as.factor(rep(1:41,each=6))
DA.kwd <-cbind(allDA.kwd,class.DAkwd)
colnames(DA.kwd)<-c("DA.val","land.c")
kruskal.test(DA.val ~ land.c, data = DA.kwd)
DT <-dunnTest(DA.val ~ land.c, data=DA.kwd, method="bonferroni")
DT <-DT$res
which(DT$P.adj<0.05)
pv.sign <-rbind(DT[471,],DT[472,],DT[473,],DT[479,],DT[484,],DT[485,],DT[486,],DT[492,],DT[502,],DT[504,],DT[515,],DT[517,],DT[534,],DT[536,],DT[547,],DT[549,],DT[567,],DT[568,],DT[569,],DT[575,],DT[580,],DT[581,],DT[582,],DT[588,],DT[601,],DT[602,],DT[603,],DT[609,],DT[614,],DT[615,],DT[616,],DT[622,],DT[636,],DT[637,],DT[638,],DT[649,],DT[650,],DT[651,])
pv.sign




## FA_between groups diff_Tukey post-hoc ##
###########################################

seq.FA<-as.matrix(c(FA.classI, FA.classII, FA.classIII, FA.classIV, FA.classV, FA.classVI),)
class.fact.FA<-as.factor(c(rep("ClassI", 5*41), rep("ClassII", 14*41), rep("ClassIII",11*41), rep("ClassIV", 26*41), rep("ClassV",82*41),rep("ClassVI",45*41)))
bgd.FA <- aov(seq.FA~class.fact.FA)
summary(bgd.FA)
anova(procD.lm(seq.FA~class.fact.FA), print.progress = FALSE, effect.type = "F")$table
Tph.FA <- TukeyHSD(bgd.FA)
Tph.FA



## FA_KW_bonferroni correction ##
#################################

FA.tot.kw<-abind(FA.classI,FA.classII,FA.classIII,FA.classIV,FA.classV,FA.classVI)
class.prov.kw<-as.factor(c(rep("cI",5),rep("cII",14),rep("cIII",11),rep("cIV",26),rep("cV",82),rep("cVI",45)))
all.kw<-abind(class.prov.kw,t(FA.tot.kw))
kwpvals <-apply(all.kw[,-1], 2, function(x) kruskal.test(x,all.kw[,1])$p.value)
kwpvals
p.adjust(kwpvals,"bonferroni")
which(p.adjust(kwpvals,"bonferroni")<0.05)



## DA_M/F Mann-Whitney test ##
##############################

wilcox.test(classIV.test.DA ~ sex.test.fact.DA)
wilcox.test(classV.test.DA ~ sex.test.fact.DA)
wilcox.test(classVI.test.DA ~ sex.test.fact.DA)
p.vals.DA<-c(0.94,0.43,0.13)
which(p.adjust(p.vals.DA,"bonferroni")<0.05)



## FA_M/F Mann-Whitney test ##
##############################

wilcox.test(classIV.test.FA ~ classIV.sex.fact.FA)
wilcox.test(classV.test.FA ~ classV.sex.fact.FA)
wilcox.test(classVI.test.FA ~ classVI.sex.fact.FA)
p.vals.FA<-c(0.10,0.60,0.04)
which(p.adjust(p.vals.FA,"bonferroni")<0.05)


# END OF LOG

